@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+ /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
  *
@@ -28,7 +28,7 @@
 #include <QDebug>
 
 #include "SwitchButton/switchbutton.h"
-#include "HoverWidget/hoverwidget.h"
+#include "ImageUtil/imageutil.h"
 #include "elipsemaskwidget.h"
 
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
@@ -45,7 +45,7 @@ extern "C" {
 
 
 #define DEFAULTFACE "/usr/share/ukui/faces/default.png"
-#define ITEMHEIGH 58
+#define ITEMHEIGH 52
 
 UserInfo::UserInfo()
 {
@@ -54,8 +54,9 @@ UserInfo::UserInfo()
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("userinfo");
+    pluginName = tr("Userinfo");
     pluginType = ACCOUNT;
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
     //构建System dbus调度对象
     sysdispatcher = new SystemDbusDispatcher;
@@ -65,16 +66,33 @@ UserInfo::UserInfo()
     _acquireAllUsersInfo();
 
 
+    readCurrentPwdConf();
     initComponent();
     initAllUserStatus();
     //设置界面用户信息
     _refreshUserInfoUI();
 
+
+//    pwdSignalMapper = new QSignalMapper(this);
+//    faceSignalMapper = new QSignalMapper(this);
+//    typeSignalMapper = new QSignalMapper(this);
+//    delSignalMapper = new QSignalMapper(this);
+
+//    faceSize = QSize(64, 64);
+//    itemSize = QSize(230, 106); //?需要比btnsize大多少？否则显示不全
+//    btnSize = QSize(222, 92);
+
+
+//    get_all_users();
+//    ui_component_init();
+//    ui_status_init();
+
 }
 
 UserInfo::~UserInfo()
 {
     delete ui;
+    delete autoSettings;
 }
 
 QString UserInfo::get_plugin_name(){
@@ -166,7 +184,8 @@ UserInfomation UserInfo::_acquireUserInfo(QString objpath){
         user.iconfile = propertyMap.find("IconFile").value().toString();
         user.passwdtype = propertyMap.find("PasswordMode").value().toInt();
         user.uid = propertyMap.find("Uid").value().toInt();
-        user.autologin = propertyMap.find("AutomaticLogin").value().toBool();
+//        user.autologin = propertyMap.find("AutomaticLogin").value().toBool();
+        user.autologin = this->getAutomaticLogin(user.username);
         user.objpath = objpath;
     }
     else
@@ -177,40 +196,197 @@ UserInfomation UserInfo::_acquireUserInfo(QString objpath){
     return user;
 }
 
+void UserInfo::readCurrentPwdConf(){
+#ifdef ENABLEPQ
+    int ret, status;
+    void *auxerror;
+    char buf[255];
+
+    pwdMsg = "";
+
+    pwdconf = pwquality_default_settings();
+    if (pwdconf == NULL) {
+        enablePwdQuality = false;
+        qDebug() << "init pwquality settings failed";
+    } else {
+        enablePwdQuality = true;
+    }
+
+    ret = pwquality_read_config(pwdconf, PWCONF, &auxerror);
+    if (ret != 0){
+        enablePwdQuality = false;
+        qDebug() << "Reading pwquality configuration file failed: " << pwquality_strerror(buf, sizeof(buf), ret, auxerror);
+    } else {
+        enablePwdQuality = true;
+    }
+
+    if (enablePwdQuality){
+        int minLen;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_MIN_LENGTH, &minLen);
+        if (!status && minLen > 0){
+            pwdOption.min_length = minLen;
+            pwdMsg += QObject::tr("min length %1\n").arg(minLen);
+
+        } else {
+            pwdMsg += "";
+        }
+
+        int digCredit;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_DIG_CREDIT, &digCredit);
+        if (!status && digCredit > 0){
+            pwdOption.dig_credit = digCredit;
+            pwdMsg += QObject::tr("min digit num %1\n").arg(digCredit);
+        } else {
+            pwdMsg += "";
+        }
+
+        int upCredit;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_UP_CREDIT, &upCredit);
+        if (!status && upCredit > 0){
+            pwdOption.up_credit = upCredit;
+            pwdMsg += QObject::tr("min upper num %1\n").arg(upCredit);
+        } else {
+            pwdMsg += "";
+        }
+
+        int lowCredit;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_LOW_CREDIT, &lowCredit);
+        if (!status && lowCredit > 0){
+            pwdOption.low_credit = lowCredit;
+            pwdMsg += QObject::tr("min lower num %1\n").arg(lowCredit);
+        } else {
+            pwdMsg += "";
+        }
+
+        int othCredit;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_OTH_CREDIT, &othCredit);
+        if (!status && othCredit > 0){
+            pwdOption.oth_credit = othCredit;
+            pwdMsg += QObject::tr("min other num %1\n").arg(othCredit);
+        } else {
+            pwdMsg += "";
+        }
+
+
+        int minClass;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_MIN_CLASS, &minClass);
+        if (!status && minClass > 0){
+            pwdOption.min_class = minClass;
+            pwdMsg += QObject::tr("min char class %1\n").arg(minClass);
+        } else {
+            pwdMsg += "";
+        }
+
+        int maxRepeat;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_MAX_REPEAT, &maxRepeat);
+        if (!status && maxRepeat > 0){
+            pwdOption.max_repeat = maxRepeat;
+            pwdMsg += QObject::tr("max repeat %1\n").arg(maxRepeat);
+        } else {
+            pwdMsg += "";
+        }
+
+        int maxClassRepeat;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_MAX_CLASS_REPEAT, &maxClassRepeat);
+        if (!status && maxClassRepeat > 0){
+            pwdOption.max_class_repeat = maxClassRepeat;
+            pwdMsg += QObject::tr("max class repeat %1\n").arg(maxClassRepeat);
+        } else {
+            pwdMsg += "";
+        }
+
+        int maxSequence;
+        status = pwquality_get_int_value(pwdconf, PWQ_SETTING_MAX_SEQUENCE, &maxSequence);
+        if (!status && maxSequence > 0){
+            pwdOption.max_class_repeat = maxSequence;
+            pwdMsg += QObject::tr("max sequence %1\n").arg(maxSequence);
+        } else {
+            pwdMsg += "";
+        }
+    }
+
+    qDebug() << "pwquality:" << pwdOption.min_length << pwdOption.min_class << pwdOption.dig_credit << pwdOption.low_credit << pwdOption.up_credit;
+    qDebug() << "pwquality msg:" << pwdMsg;
+#endif
+}
+
 void UserInfo::initComponent(){
     //样式表
-    pluginWidget->setStyleSheet("background: #ffffff;");
+//    pluginWidget->setStyleSheet("background: #ffffff;");
 
-    ui->currentUserWidget->setStyleSheet("QWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
-    ui->autoLoginWidget->setStyleSheet("QWidget{background: #F4F4F4; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
+//    ui->currentUserWidget->setStyleSheet("QWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
+//    ui->autoLoginWidget->setStyleSheet("QWidget{background: #F4F4F4; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
 
-    QString btnQss = QString("QPushButton{background: #FFFFFF; border-radius: 4px;}");
-    ui->changePwdBtn->setStyleSheet(btnQss);
-    ui->changeTypeBtn->setStyleSheet(btnQss);
+//    QString btnQss = QString("QPushButton{background: #FFFFFF; border-radius: 4px;}");
+//    ui->changePwdBtn->setStyleSheet(btnQss);
+//    ui->changeTypeBtn->setStyleSheet(btnQss);
 
-    ui->addUserWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
+//    ui->addUserWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
 
-    nopwdSwitchBtn = new SwitchButton(ui->nopwdLoginWidget);
+//    QString filename = "/etc/lightdm/lightdm.conf";
+//    autoSettings = new QSettings(filename, QSettings::IniFormat);
+
+    ui->listWidget->setStyleSheet("QListWidget::Item:hover{background:palette(base);}");
+
+    addWgt = new HoverWidget("");
+    addWgt->setObjectName("addwgt");
+    addWgt->setMinimumSize(QSize(580, 50));
+    addWgt->setMaximumSize(QSize(960, 50));
+    addWgt->setStyleSheet("HoverWidget#addwgt{background: palette(button); border-radius: 4px;}HoverWidget:hover:!pressed#addwgt{background: #3D6BE5; border-radius: 4px;}");
+
+    QHBoxLayout *addLyt = new QHBoxLayout;
+
+    QLabel * iconLabel = new QLabel();
+    QLabel * textLabel = new QLabel(tr("Add new user"));
+    QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+    iconLabel->setPixmap(pixgray);
+    addLyt->addWidget(iconLabel);
+    addLyt->addWidget(textLabel);
+    addLyt->addStretch();
+    addWgt->setLayout(addLyt);
+
+    // 悬浮改变Widget状态
+    connect(addWgt, &HoverWidget::enterWidget, this, [=](QString mname){
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "white", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(base);");
+
+    });
+    // 还原状态
+    connect(addWgt, &HoverWidget::leaveWidget, this, [=](QString mname){
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(windowText);");
+    });
+
+    connect(addWgt, &HoverWidget::widgetClicked, this, [=](QString mname){
+        showCreateUserDialog();
+    });
+
+    ui->addLyt->addWidget(addWgt);
+
+    nopwdSwitchBtn = new SwitchButton(ui->nopwdLoginFrame);
     ui->nopwdHorLayout->addWidget(nopwdSwitchBtn);
 
-    autoLoginSwitchBtn = new SwitchButton(ui->autoLoginWidget);
+    autoLoginSwitchBtn = new SwitchButton(ui->autoLoginFrame);
     ui->autoLoginHorLayout->addWidget(autoLoginSwitchBtn);
 
 
-    ui->listWidget->setStyleSheet("QListWidget{border: none}");
-    ui->listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+//    ui->listWidget->setStyleSheet("QListWidget{border: none}");
+//    ui->listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+//    ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->listWidget->setSpacing(0);
 
     ElipseMaskWidget * mainElipseMaskWidget = new ElipseMaskWidget(ui->currentUserFaceLabel);
-    mainElipseMaskWidget->setBgColor("#F4F4F4");
     mainElipseMaskWidget->setGeometry(0, 0, ui->currentUserFaceLabel->width(), ui->currentUserFaceLabel->height());
 
     //设置添加用户的图标
-    ui->addBtn->setIcon(QIcon("://img/plugins/userinfo/add.png"));
-    ui->addBtn->setIconSize(ui->addBtn->size());
+//    ui->addBtn->setIcon(QIcon("://img/plugins/userinfo/add.png"));
+//    ui->addBtn->setIconSize(ui->addBtn->size());
+//    ui->addBtn->setStyleSheet("QPushButton{background-color:transparent;}");
 
     ui->currentUserFaceLabel->installEventFilter(this);
+//    ui->addUserFrame->installEventFilter(this);
 
     //修改当前用户密码的回调
     connect(ui->changePwdBtn, &QPushButton::clicked, this, [=](bool checked){
@@ -228,6 +404,14 @@ void UserInfo::initComponent(){
         showChangeTypeDialog(user.username);
     });
 
+    connect(ui->changeValidBtn, &QPushButton::clicked, this, [=](bool checked){
+        Q_UNUSED(checked)
+        UserInfomation user = allUserInfoMap.value(g_get_user_name());
+
+        showChangeValidDialog(user.username);
+
+    });
+
     //修改当前用户免密登录
     connect(nopwdSwitchBtn, &SwitchButton::checkedChanged, [=](bool checked){
 
@@ -253,10 +437,27 @@ void UserInfo::initComponent(){
     connect(autoLoginSwitchBtn, &SwitchButton::checkedChanged, [=](bool checked){
         UserInfomation user = allUserInfoMap.value(g_get_user_name());
 
+
         UserDispatcher * userdispatcher  = new UserDispatcher(user.objpath);
 
-        userdispatcher->change_user_autologin(checked);
 
+//        bool status = userdispatcher->get_autoLogin_status();
+
+        bool status = this->getAutomaticLogin(user.username);
+
+
+        if ((checked != status)) {
+            if (checked) {
+                userdispatcher->change_user_autologin(user.username);
+            } else {
+                userdispatcher->change_user_autologin("");
+            }
+        }
+
+//        bool lstStatus = userdispatcher->get_autoLogin_status();
+
+//        bool lstStatus = this->getAutomaticLogin(user.username);
+//        autoLoginSwitchBtn->setChecked(lstStatus);
     });
 
     //成功删除用户的回调
@@ -265,10 +466,10 @@ void UserInfo::initComponent(){
     });
 
     //新建用户的回调
-    connect(ui->addBtn, &QPushButton::clicked, this, [=](bool checked){
-        Q_UNUSED(checked)
-        showCreateUserDialog();
-    });
+//    connect(ui->addBtn, &QPushButton::clicked, this, [=](bool checked){
+//        Q_UNUSED(checked)
+//        showCreateUserDialog();
+//    });
 
     //成功新建用户的回调
     connect(sysdispatcher, &SystemDbusDispatcher::createuserdone, this, [=](QString objPath){
@@ -278,7 +479,7 @@ void UserInfo::initComponent(){
 
 void UserInfo::_resetListWidgetHeigh(){
     //设置其他用户控件的总高度
-    ui->listWidget->setFixedHeight((allUserInfoMap.count() - 1) * ITEMHEIGH);
+    ui->listWidget->setFixedHeight((allUserInfoMap.count()) * ITEMHEIGH);
 }
 
 void UserInfo::initAllUserStatus(){
@@ -344,9 +545,8 @@ void UserInfo::_refreshUserInfoUI(){
 
 void UserInfo::_buildWidgetForItem(UserInfomation user){
     HoverWidget * baseWidget = new HoverWidget(user.username);
-    baseWidget->setStyleSheet("background: #ffffff;");
-//    baseWidget->setMinimumSize(550,50);
-//    baseWidget->setMaximumSize(960,50);
+    baseWidget->setMinimumSize(550,50);
+    baseWidget->setMaximumSize(960,50);
     baseWidget->setAttribute(Qt::WA_DeleteOnClose);
 
     QHBoxLayout * baseVerLayout = new QHBoxLayout(baseWidget);
@@ -357,9 +557,9 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     baseHorLayout->setSpacing(16);
     baseHorLayout->setMargin(0);
 
-    QWidget * widget = new QWidget(baseWidget);
+    QFrame * widget = new QFrame(baseWidget);
+    widget->setFrameShape(QFrame::Shape::Box);
     widget->setFixedHeight(50);
-    widget->setStyleSheet("background: #F4F4F4; border-radius: 4px;");
 
     QHBoxLayout * mainHorLayout = new QHBoxLayout(widget);
     mainHorLayout->setSpacing(16);
@@ -387,7 +587,7 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     QPushButton * typeBtn = new QPushButton(widget);
     typeBtn->setFixedSize(88, 36);
     typeBtn->setText(tr("Change type"));
-    typeBtn->setStyleSheet(btnQss);
+//    typeBtn->setStyleSheet(btnQss);
     connect(typeBtn, &QPushButton::clicked, this, [=](bool checked){
         Q_UNUSED(checked)
         showChangeTypeDialog(user.username);
@@ -397,7 +597,7 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     QPushButton * pwdBtn = new QPushButton(widget);
     pwdBtn->setFixedSize(88, 36);
     pwdBtn->setText(tr("Change pwd"));
-    pwdBtn->setStyleSheet(btnQss);
+//    pwdBtn->setStyleSheet(btnQss);
     connect(pwdBtn, &QPushButton::clicked, this, [=](bool checked){
         Q_UNUSED(checked)
         showChangePwdDialog(user.username);
@@ -415,7 +615,7 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     QPushButton * delBtn = new QPushButton(baseWidget);
     delBtn->setFixedSize(60, 36);
     delBtn->setText(tr("Delete"));
-    delBtn->setStyleSheet("QPushButton{background: #FA6056; border-radius: 4px}");
+//    delBtn->setStyleSheet("QPushButton{background: #FA6056; border-radius: 4px}");
     delBtn->hide();
     connect(delBtn, &QPushButton::clicked, this, [=](bool checked){
         Q_UNUSED(checked)
@@ -437,6 +637,8 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
 
     baseHorLayout->addWidget(widget);
     baseHorLayout->addWidget(delBtn, Qt::AlignVCenter);
+    baseHorLayout->addSpacing(4);
+
 
     baseVerLayout->addLayout(baseHorLayout);
 //    baseVerLayout->addStretch();
@@ -444,7 +646,7 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     baseWidget->setLayout(baseVerLayout);
 
     QListWidgetItem * item = new QListWidgetItem(ui->listWidget);
-    item->setSizeHint(QSize(ui->listWidget->width(), ITEMHEIGH));
+    item->setSizeHint(QSize(ui->listWidget->width() - 2, ITEMHEIGH));
     item->setData(Qt::UserRole, QVariant(user.objpath));
     ui->listWidget->setItemWidget(item, baseWidget);
 
@@ -460,10 +662,11 @@ void UserInfo::showCreateUserDialog(){
     }
 
     CreateUserDialog * dialog = new CreateUserDialog(usersStringList);
+    dialog->setRequireLabel(pwdMsg);
     connect(dialog, &CreateUserDialog::newUserWillCreate, this, [=](QString uName, QString pwd, QString pin, int aType){
         createUser(uName, pwd, pin, aType);
     });
-    dialog->show();
+    dialog->exec();
 }
 
 void UserInfo::createUser(QString username, QString pwd, QString pin, int atype){
@@ -504,7 +707,7 @@ void UserInfo::showDeleteUserDialog(QString username){
     connect(dialog, &DelUserDialog::removefile_send, this, [=](bool removeFile, QString userName){
         deleteUser(removeFile, userName);
     });
-    dialog->open();
+    dialog->exec();
 }
 
 void UserInfo::deleteUser(bool removefile, QString username){
@@ -512,6 +715,16 @@ void UserInfo::deleteUser(bool removefile, QString username){
 
     UserInfomation user = (UserInfomation)(allUserInfoMap.find(username).value());
 
+    // hidden the item when click delete user button
+    QListWidgetItem *item =  otherUserItemMap.find(user.objpath).value();
+    ui->listWidget->setItemHidden(item, true);
+
+    sysdispatcher->delete_user(user.uid, removefile);
+}
+
+void UserInfo::delete_user_slot(bool removefile, QString username){
+    UserInfomation user = (UserInfomation)(allUserInfoMap.find(username).value());
+
     sysdispatcher->delete_user(user.uid, removefile);
 }
 
@@ -531,6 +744,21 @@ void UserInfo::deleteUserDone(QString objpath){
     _resetListWidgetHeigh();
 }
 
+void UserInfo::showChangeValidDialog(QString username){
+    if (allUserInfoMap.keys().contains(username)){
+        UserInfomation user = allUserInfoMap.value(username);
+
+        ChangeValidDialog * dialog = new ChangeValidDialog(user.username);
+        dialog->setUserName();
+        dialog->setUserLogo(user.iconfile);
+        dialog->setUserType(_accountTypeIntToString(user.accounttype));
+        dialog->exec();
+
+    } else {
+        qDebug() << "User Data Error When Change User type";
+    }
+}
+
 
 void UserInfo::showChangeTypeDialog(QString username){
     if (allUserInfoMap.keys().contains(username)){
@@ -541,11 +769,12 @@ void UserInfo::showChangeTypeDialog(QString username){
         dialog->setUsername(user.username);
         dialog->setCurrentAccountTypeLabel(_accountTypeIntToString(user.accounttype));
         dialog->setCurrentAccountTypeBtn(user.accounttype);
+        dialog->forbidenChange(adminnum);
 //        connect(dialog, SIGNAL(type_send(int,QString,bool)), this, SLOT(change_accounttype_slot(int,QString,bool)));
         connect(dialog, &ChangeTypeDialog::type_send, this, [=](int atype, QString userName){
             changeUserType(atype, userName);
         });
-        dialog->show();
+        dialog->exec();
 
     } else {
         qDebug() << "User Data Error When Change User type";
@@ -580,7 +809,7 @@ void UserInfo::showChangeFaceDialog(QString username){
     connect(dialog, &ChangeFaceDialog::face_file_send, [=](QString faceFile, QString userName){
         changeUserFace(faceFile, userName);
     });
-    dialog->show();
+    dialog->exec();
 }
 
 void UserInfo::changeUserFace(QString facefile, QString username){
@@ -588,12 +817,7 @@ void UserInfo::changeUserFace(QString facefile, QString username){
 
     UserDispatcher * userdispatcher  = new UserDispatcher(user.objpath);
     userdispatcher->change_user_face(facefile);
-
-    //重新获取全部用户QMap
-    _acquireAllUsersInfo();
-
-    //更新界面显示
-    _refreshUserInfoUI();
+//    userdispatcher->change_user_face(QString("/home/%1/.face").arg(user.username));
 
     //拷贝设置的头像文件到~/.face
     sysinterface = new QDBusInterface("com.control.center.qt.systemdbus",
@@ -610,6 +834,13 @@ void UserInfo::changeUserFace(QString facefile, QString username){
 
     QDBusReply<QString> reply =  sysinterface->call("systemRun", QVariant(cmd));
 
+
+    //重新获取全部用户QMap
+    _acquireAllUsersInfo();
+
+    //更新界面显示
+    _refreshUserInfoUI();
+
     Q_UNUSED(reply)
 }
 
@@ -624,12 +855,11 @@ void UserInfo::showChangePwdDialog(QString username){
         connect(dialog, &ChangePwdDialog::passwd_send, this, [=](QString pwd, QString userName){
             changeUserPwd(pwd, userName);
         });
-        dialog->show();
+        dialog->exec();
 
     } else {
         qDebug() << "User Info Data Error When Change User type";
     }
-
 }
 
 
@@ -648,12 +878,29 @@ bool UserInfo::eventFilter(QObject *watched, QEvent *event){
     if (watched == ui->currentUserFaceLabel){
         if (event->type() == QEvent::MouseButtonPress){
             QMouseEvent * mouseEvent = static_cast<QMouseEvent *>(event);
-            if (mouseEvent->button() == Qt::LeftButton){
-                showChangeFaceDialog(ui->userNameLabel->text());
+            if (mouseEvent->button() == Qt::LeftButton ){
+                if(watched == ui->currentUserFaceLabel){
+                    showChangeFaceDialog(ui->userNameLabel->text());
+                }
                 return true;
-            } else
+            } else {
                 return false;
+            }
         }
     }
+
     return QObject::eventFilter(watched, event);
 }
+
+bool UserInfo::getAutomaticLogin(QString username) {
+
+    QString filename = "/etc/lightdm/lightdm.conf";
+    autoSettings = new QSettings(filename, QSettings::IniFormat);
+    autoSettings->beginGroup("SeatDefaults");
+
+    QString autoUser = autoSettings->value("autologin-user", "").toString();
+
+    autoSettings->endGroup();
+
+    return autoUser == username ? true : false;
+}
