@@ -25,17 +25,13 @@
 Audio::Audio()
 {
     ui = new Ui::Audio;
-    pluginWidget = new CustomWidget;
+    pluginWidget = new UkmediaMainWidget;
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
+//    pluginWidget->setStyleSheet("background: #ffffff;");
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("audio");
+    pluginName = tr("Audio");
     pluginType = DEVICES;
-
-    connect(ui->soundthemeBtn, SIGNAL(clicked()), this, SLOT(change_soundtheme_page()));
-    connect(ui->preferencesBtn, SIGNAL(clicked()), this, SLOT(change_preference_page()));
-
-    connect(ui->soundsettingsBtn, SIGNAL(clicked()), this, SLOT(sound_settings_btn_clicked_slot()));
 }
 
 Audio::~Audio()
@@ -51,7 +47,7 @@ int Audio::get_plugin_type(){
     return pluginType;
 }
 
-CustomWidget *Audio::get_plugin_ui(){
+QWidget *Audio::get_plugin_ui(){
     return pluginWidget;
 }
 
@@ -59,17 +55,3 @@ void Audio::plugin_delay_control(){
 
 }
 
-void Audio::change_soundtheme_page(){
-    ui->StackedWidget->setCurrentIndex(1);
-}
-
-void Audio::change_preference_page(){
-    ui->StackedWidget->setCurrentIndex(2);
-}
-
-void Audio::sound_settings_btn_clicked_slot(){
-    QString cmd = "ukui-volume-control";
-
-    QProcess process(this);
-    process.startDetached(cmd);
-}
