@@ -22,6 +22,8 @@
 
 #include <QDialog>
 #include <QFileDialog>
+#include <QPainter>
+#include <QPainterPath>
 
 namespace Ui {
 class addShortcutDialog;
@@ -41,6 +43,12 @@ public:
 
     void setUpdateEnv(QString path, QString name, QString exec);
 
+    void refreshCertainChecked();
+
+protected:
+    void paintEvent(QPaintEvent *);
+
+
 private:
     Ui::addShortcutDialog *ui;
 
