@@ -28,6 +28,20 @@
 #include "realizeshortcutwheel.h"
 #include "defineshortcutitem.h"
 
+
+/* qt会将glib里的signals成员识别为宏，所以取消该宏
+ * 后面如果用到signals时，使用Q_SIGNALS代替即可
+ **/
+#ifdef signals
+#undef signals
+#endif
+
+extern "C" {
+#include <glib.h>
+#include <glib/gi18n.h>
+}
+
+
 #define ITEMHEIGH 36
 
 //快捷键屏蔽键
@@ -60,24 +74,27 @@ Shortcut::Shortcut()
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("shortcut");
+    pluginName = tr("Shortcut");
     pluginType = DEVICES;
 
-    pluginWidget->setStyleSheet("background: #ffffff;");
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+    ui->title2Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
-    ui->generalListWidget->setStyleSheet("QListWidget#generalListWidget{background: #ffffff; border: none;}");
+//    pluginWidget->setStyleSheet("background: #ffffff;");
 
-    ui->showBtn->setStyleSheet("QPushButton{background: #E9E9E9; border-radius: 4px;}"
-                               "QPushButton:hover:!pressed{background: #3d6be5; border-radius: 4px;}"
-                               "QPushButton:hover:pressed{background: #415FC4; border-radius: 4px;}");
+//    ui->generalListWidget->setStyleSheet("QListWidget#generalListWidget{background: #ffffff; border: none;}");
 
-    ui->resetBtn->setStyleSheet("QPushButton{background: #E9E9E9; border-radius: 4px;}"
-                               "QPushButton:hover:!pressed{background: #3d6be5; border-radius: 4px;}"
-                               "QPushButton:hover:pressed{background: #415FC4; border-radius: 4px;}");
+//    ui->showBtn->setStyleSheet("QPushButton{background: #E9E9E9; border-radius: 4px;}"
+//                               "QPushButton:hover:!pressed{background: #3d6be5; border-radius: 4px;}"
+//                               "QPushButton:hover:pressed{background: #415FC4; border-radius: 4px;}");
 
-    ui->customListWidget->setStyleSheet("QListWidget#customListWidget{background: #ffffff; border: none;}");
+//    ui->resetBtn->setStyleSheet("QPushButton{background: #E9E9E9; border-radius: 4px;}"
+//                               "QPushButton:hover:!pressed{background: #3d6be5; border-radius: 4px;}"
+//                               "QPushButton:hover:pressed{background: #415FC4; border-radius: 4px;}");
 
-    ui->addWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
+//    ui->customListWidget->setStyleSheet("QListWidget#customListWidget{background: #ffffff; border: none;}");
+
+//    ui->addWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
 
     pKeyMap = new KeyMap;
     addDialog = new addShortcutDialog();
@@ -115,13 +132,13 @@ void Shortcut::plugin_delay_control(){
 }
 
 void Shortcut::setupComponent(){
-    ui->addLabel->setPixmap(QPixmap("://img/plugins/printer/add.png"));
+//    ui->addLabel->setPixmap(QPixmap("://img/plugins/printer/add.png"));
 
     ui->generalListWidget->setFocusPolicy(Qt::NoFocus);
     ui->generalListWidget->setSelectionMode(QAbstractItemView::NoSelection);
     ui->generalListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->generalListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    ui->generalListWidget->setSpacing(0);
+    ui->generalListWidget->setSpacing(1);
 
     ui->customListWidget->setFocusPolicy(Qt::NoFocus);
     ui->customListWidget->setSelectionMode(QAbstractItemView::NoSelection);
@@ -130,19 +147,53 @@ void Shortcut::setupComponent(){
     ui->customListWidget->setSpacing(0);
 //    ui->customListWidget->setFixedHeight((showList.length() * ITEMHEIGH));
 
-    ui->addWidget->installEventFilter(this);
+    addWgt = new HoverWidget("");
+    addWgt->setObjectName("addwgt");
+    addWgt->setMinimumSize(QSize(580, 50));
+    addWgt->setMaximumSize(QSize(960, 50));
+    addWgt->setStyleSheet("HoverWidget#addwgt{background: palette(button); border-radius: 4px;}HoverWidget:hover:!pressed#addwgt{background: #3D6BE5; border-radius: 4px;}");
+
+    QHBoxLayout *addLyt = new QHBoxLayout;
+
+    QLabel * iconLabel = new QLabel();
+    QLabel * textLabel = new QLabel(tr("Add custom shortcut"));
+    QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+    iconLabel->setPixmap(pixgray);
+    addLyt->addWidget(iconLabel);
+    addLyt->addWidget(textLabel);
+    addLyt->addStretch();
+    addWgt->setLayout(addLyt);
+
+    // 悬浮改变Widget状态
+    connect(addWgt, &HoverWidget::enterWidget, this, [=](QString mname){
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "white", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(base);");
+
+    });
+    // 还原状态
+    connect(addWgt, &HoverWidget::leaveWidget, this, [=](QString mname){
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(windowText);");
+    });
+
+    ui->addLyt->addWidget(addWgt);
+
+
+//    ui->addFrame->installEventFilter(this);
     ui->generalListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
 
     ui->resetBtn->hide();
 
-    //
-    ui->title2Label->hide();
-    ui->customListWidget->hide();
-    ui->addWidget->hide();
-
 }
 
 void Shortcut::setupConnect(){
+
+    connect(addWgt, &HoverWidget::widgetClicked, this, [=](QString mname){
+        addDialog->exec();
+    });
+
     connect(ui->showBtn, &QPushButton::clicked, [=]{
         QMap<QString, QString> systemMap;
         QMap<QString, QString> desktopMap;
@@ -157,10 +208,14 @@ void Shortcut::setupConnect(){
 
         }
         QMap<QString, QMap<QString, QString>> generalMaps;
-        generalMaps.insert(tr("Desktop"), desktopMap);
-        generalMaps.insert(tr("System"), systemMap);
+        if (desktopMap.count() != 0) {
+            generalMaps.insert("Desktop", desktopMap);
+        }
+//        if (systemMap.count() != 0) {
+//            generalMaps.insert("System", systemMap);
+//        }
         showDialog->buildComponent(generalMaps);
-        showDialog->show();
+        showDialog->exec();
     });
 
     connect(addDialog, &addShortcutDialog::shortcutInfoSignal, [=](QString path, QString name, QString exec){
@@ -181,7 +236,8 @@ void Shortcut::setupConnect(){
         if (!selectedItems.isEmpty()){
             QListWidgetItem * sItem = selectedItems.first();
             DefineShortcutItem * wItem = dynamic_cast<DefineShortcutItem *>(ui->generalListWidget->itemWidget(sItem));
-            KeyEntry * currentEntry = dynamic_cast<KeyEntry *>(wItem->userData(Qt::UserRole));
+//            KeyEntry * currentEntry = dynamic_cast<KeyEntry *>(wItem->userData(Qt::UserRole));
+            KeyEntry * currentEntry = wItem->property("userData").value<KeyEntry *>();
 
             const QByteArray id(currentEntry->gsSchema.toLatin1().data());
             QGSettings * settings = new QGSettings(id);
@@ -204,7 +260,7 @@ void Shortcut::initFunctionStatus(){
     pThread = new QThread;
     pWorker = new GetShortcutWorker;
     connect(pWorker, &GetShortcutWorker::generalShortcutGenerate, this, [=](QString schema, QString key, QString value){
-//        qDebug() << "general shortcut" << schema << key << value;
+        //qDebug() << "general shortcut" << schema << key << value;
         KeyEntry * generalKeyEntry = new KeyEntry;
         generalKeyEntry->gsSchema = schema;
         generalKeyEntry->keyStr = key;
@@ -213,7 +269,7 @@ void Shortcut::initFunctionStatus(){
 
     });
     connect(pWorker, &GetShortcutWorker::customShortcutGenerate, this, [=](QString path, QString name, QString binding, QString action){
-//        qDebug() << "custom shortcut" << path << name << binding;
+        //qDebug() << "custom shortcut" << path << name << binding;
         KeyEntry * customKeyEntry = new KeyEntry;
         customKeyEntry->gsSchema = KEYBINDINGS_CUSTOM_SCHEMA;
         customKeyEntry->gsPath = path;
@@ -250,8 +306,25 @@ void Shortcut::initFunctionStatus(){
 void Shortcut::appendGeneralItems(){
     for (KeyEntry * gkeyEntry: generalEntries){
         if (showList.contains(gkeyEntry->keyStr)){
-            DefineShortcutItem * singleWidget = new DefineShortcutItem(gkeyEntry->keyStr, gkeyEntry->valueStr);
-            singleWidget->setUserData(Qt::UserRole, gkeyEntry);
+
+            GSettingsSchema * pSettings;
+
+            pSettings = g_settings_schema_source_lookup(g_settings_schema_source_new_from_directory("/usr/share/glib-2.0/schemas/", g_settings_schema_source_get_default(), FALSE, NULL),
+                                                        KEYBINDINGS_DESKTOP_SCHEMA,
+                                                        FALSE);
+
+            QByteArray ba = QString("ukui-settings-daemon").toLatin1();
+            QByteArray ba1 = gkeyEntry->keyStr.toLatin1();
+
+            GSettingsSchemaKey * keyObj = g_settings_schema_get_key(pSettings, ba1.data());
+
+            char * i18nKey;
+            i18nKey = const_cast<char *>(g_dgettext(ba.data(), g_settings_schema_key_get_summary(keyObj)));
+
+            DefineShortcutItem * singleWidget = new DefineShortcutItem(QString(i18nKey), gkeyEntry->valueStr);
+            singleWidget->setFrameShape(QFrame::Shape::Box);
+//            singleWidget->setUserData(Qt::UserRole, gkeyEntry);
+            singleWidget->setProperty("userData", QVariant::fromValue(gkeyEntry));
 
             CustomLineEdit * line = singleWidget->lineeditComponent();
             connect(line, &CustomLineEdit::shortcutCodeSignals, this, [=](QList<int> keyCode){
@@ -276,7 +349,8 @@ void Shortcut::buildCustomItem(KeyEntry * nkeyEntry){
     DefineShortcutItem * singleWidget = new DefineShortcutItem(nkeyEntry->nameStr, nkeyEntry->bindingStr);
     singleWidget->setDeleteable(true);
     singleWidget->setUpdateable(true);
-    singleWidget->setUserData(Qt::UserRole, nkeyEntry);
+//    singleWidget->setUserData(Qt::UserRole, nkeyEntry);
+    singleWidget->setProperty("userData", QVariant::fromValue(nkeyEntry));
     connect(singleWidget, &DefineShortcutItem::updateShortcutSignal, [=]{
         addDialog->setTitleText(QObject::tr("Update Shortcut"));
         addDialog->setUpdateEnv(nkeyEntry->gsPath, nkeyEntry->nameStr, nkeyEntry->actionStr);
@@ -341,8 +415,8 @@ void Shortcut::initItemsStyle(QListWidget *listWidget){
 
         QWidget * widget = listWidget->itemWidget(listWidget->item(row));
         DefineShortcutItem * pShortcutItem = dynamic_cast<DefineShortcutItem *>(widget);
-        pShortcutItem->widgetComponent()->setStyleSheet(style);
-        pShortcutItem->btnComponent()->setStyleSheet(subStyle);
+//        pShortcutItem->widgetComponent()->setStyleSheet(style);
+//        pShortcutItem->btnComponent()->setStyleSheet(subStyle);
     }
 }
 
@@ -397,7 +471,8 @@ void Shortcut::createNewShortcut(QString path, QString name, QString exec){
                 DefineShortcutItem * widgetItem = dynamic_cast<DefineShortcutItem *>(ui->customListWidget->itemWidget(item));
                 widgetItem->setShortcutName(name);
                 KeyEntry * uKeyentry = customEntries.at(i);
-                widgetItem->setUserData(Qt::UserRole, uKeyentry);
+//                widgetItem->setUserData(Qt::UserRole, uKeyentry);
+                widgetItem->setProperty("userData", QVariant::fromValue(uKeyentry));
             }
         }
     }
@@ -443,7 +518,8 @@ void Shortcut::newBindingRequest(QList<int> keyCode){
     CustomLineEdit * current = qobject_cast<CustomLineEdit *>(object); //孙子
     QWidget * widget = current->parentWidget();
     DefineShortcutItem * widgetItem = dynamic_cast<DefineShortcutItem *>(widget->parentWidget());
-    KeyEntry * nkeyEntry = dynamic_cast<KeyEntry *>(widgetItem->userData(Qt::UserRole));
+//    KeyEntry * nkeyEntry = dynamic_cast<KeyEntry *>(widgetItem->userData(Qt::UserRole));
+    KeyEntry * nkeyEntry = widgetItem->property("userData").value<KeyEntry *>();
 
     QString shortcutString = getBindingName(keyCode);
 
@@ -467,6 +543,9 @@ void Shortcut::newBindingRequest(QList<int> keyCode){
 
     current->setText(shortcutString);
 
+    //已经设置了值，清除焦点不再监听
+    current->clearFocus();
+
     if (nkeyEntry->gsPath.isEmpty()){ //非自定义快捷键的修改
         const QByteArray iid(nkeyEntry->gsSchema.toLatin1().data());
         QGSettings * settings = new QGSettings(iid);
@@ -500,6 +579,11 @@ void Shortcut::newBindingRequest(QList<int> keyCode){
     }
 }
 
+/**
+ * @brief Shortcut::getBindingName
+ * @param keyCode
+ * @return
+ */
 QString Shortcut::getBindingName(QList<int> keyCode){
     QStringList tmpList;
     for (int keycode : keyCode){
@@ -528,20 +612,20 @@ bool Shortcut::keyIsForbidden(QString key){
     return false;
 }
 
-bool Shortcut::eventFilter(QObject *watched, QEvent *event){
-    if (watched == ui->addWidget){
-        if (event->type() == QEvent::MouseButtonPress){
-            QMouseEvent * mouseEvent = static_cast<QMouseEvent *>(event);
-            if (mouseEvent->button() == Qt::LeftButton){
-                addDialog->setTitleText(QObject::tr("Add Shortcut"));
-                addDialog->show();
-                return true;
-            } else
-                return false;
-        }
-    }
-    return QObject::eventFilter(watched, event);
-}
+//bool Shortcut::eventFilter(QObject *watched, QEvent *event){
+//    if (watched == ui->addFrame){
+//        if (event->type() == QEvent::MouseButtonPress){
+//            QMouseEvent * mouseEvent = static_cast<QMouseEvent *>(event);
+//            if (mouseEvent->button() == Qt::LeftButton){
+//                addDialog->setTitleText(QObject::tr("Add Shortcut"));
+//                addDialog->exec();
+//                return true;
+//            } else
+//                return false;
+//        }
+//    }
+//    return QObject::eventFilter(watched, event);
+//}
 
 //bool Shortcut::event(QEvent *event){
 //    qDebug() << "---111--->";
