@@ -23,9 +23,12 @@
 #include "kylin_network_interface.h"
 
 
-#include <QGSettings/QGSettings>
+#include <QGSettings>
 #include <QProcess>
 #include <QTimer>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include <QDir>
 
 
 #define CONTROL_CENTER_WIFI "org.ukui.control-center.wifi.switch"
@@ -36,50 +39,31 @@ NetConnect::NetConnect():m_wifiList(new Wifi)
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("netconnect");
+    pluginName = tr("Netconnect");
     pluginType = NETWORK;
 
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+    ui->title2Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
+    ui->detailBtn->setText(tr("Network settings"));
+
     wifiBtn = new SwitchButton();
 
-    pluginWidget->setStyleSheet("background: #ffffff;");
-
-
-    ui->statusListWidget->setStyleSheet("QListWidget#statusListWidget{border: none;}");
-    ui->availableListWidget->setStyleSheet("QListWidget#availableListWidget{border: none;}");
-
-    ui->statusListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    ui->statusListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    ui->availableListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    ui->availableListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-
-    ui->statusListWidget->setSpacing(0);
-    ui->availableListWidget->setSpacing(0);
-    ui->statusListWidget->setFocusPolicy(Qt::NoFocus);
-    ui->availableListWidget->setFocusPolicy(Qt::NoFocus);
-    ui->statusListWidget->setSelectionMode(QAbstractItemView::NoSelection);
-    ui->availableListWidget->setSelectionMode(QAbstractItemView::NoSelection);
-
-//    ui->detailBtn->setStyleSheet("QPushButton{border: none;}");
-
-    ui->openWifiWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
     ui->openWIifLayout->addWidget(wifiBtn);
 
-    ui->openWifiWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-    ui->openWIifLayout->addWidget(wifiBtn);
-
-    //构建网络配置对象
-    nmg  = new QNetworkConfigurationManager();
     initComponent();
 
-    getNetList();
+//    getNetList();
 }
 
 NetConnect::~NetConnect()
 {
     delete ui;
-    delete nmg;
-//    delete wifiBtn;
     delete m_gsettings;
+    // TODO: A segment error will be reported after delete
+//    if (wifiBtn) {
+//        delete wifiBtn;
+//    }
 }
 
 QString NetConnect::get_plugin_name(){
@@ -99,12 +83,13 @@ void NetConnect::plugin_delay_control(){
 }
 
 void NetConnect::initComponent(){
+
     const QByteArray id(CONTROL_CENTER_WIFI);
     if(QGSettings::isSchemaInstalled(id)) {
 //        qDebug()<<"isSchemaInstalled"<<endl;
         m_gsettings = new QGSettings(id);
 
-//        监听key的value是否发生了变化
+        //  监听key的value是否发生了变化
         connect(m_gsettings, &QGSettings::changed, this, [=] (const QString &key) {
 //            qDebug()<<"status changed ------------>"<<endl;
             if (key == "switchor") {
@@ -114,25 +99,41 @@ void NetConnect::initComponent(){
         });
     }
 
-    //构建网络状态组件
-//    rebuildNetStatusComponent();
-
-    //网络配置变化回调
-//    connect(nmg, &QNetworkConfigurationManager::configurationChanged, this, [=](const QNetworkConfiguration &config){
-//        Q_UNUSED(config)
-//        rebuildNetStatusComponent();
-
-//    });
-
     //详细设置按钮connect
     connect(ui->detailBtn, &QPushButton::clicked, this, [=](bool checked){
         Q_UNUSED(checked)
         runExternalApp();
     });
 
+    connect(ui->RefreshBtn, &QPushButton::clicked, this, [=](bool checked){
+        Q_UNUSED(checked)
+        clearContent();
+        ui->waitLabel->setVisible(true);
+        ui->statuswaitLabel->setVisible(true);
+        ui->RefreshBtn->setEnabled(false);
+        wifiBtn->setEnabled(false);
+        QTimer::singleShot(1*1000,this,SLOT(getNetList()));
+    });
 
-    wifiBtn->setChecked(getSwitchStatus("switch"));
-    connect(wifiBtn,SIGNAL(checkedChanged(bool)), this, SLOT(wifiSwitchSlot(bool)));
+    if (getwifiisEnable()) {
+        wifiBtn->setChecked(getInitStatus());
+    }
+    connect(wifiBtn, &SwitchButton::checkedChanged, this,[=](bool checked){
+        clearContent();
+        ui->waitLabel->setVisible(true);
+        ui->statuswaitLabel->setVisible(true);
+        ui->RefreshBtn->setEnabled(false);
+        wifiBtn->setEnabled(false);
+
+        wifiBtn->blockSignals(true);
+        wifiSwitchSlot(checked);
+        wifiBtn->blockSignals(false);
+    });
+
+    ui->RefreshBtn->setEnabled(false);
+    wifiBtn->setEnabled(false);
+
+    emit ui->RefreshBtn->clicked(true);
 }
 
 void NetConnect::rebuildNetStatusComponent(QString iconPath, QString netName){
@@ -144,19 +145,20 @@ void NetConnect::rebuildNetStatusComponent(QString iconPath, QString netName){
     baseVerLayout->setSpacing(0);
     baseVerLayout->setContentsMargins(0, 0, 0, 2);
 
-    QWidget * devWidget = new QWidget(baseWidget);
-    devWidget->setMinimumWidth(550);
-    devWidget->setMaximumWidth(960);
-    devWidget->setMinimumHeight(50);
-    devWidget->setMaximumHeight(50);
+    QFrame * devFrame = new QFrame(baseWidget);
+    devFrame->setFrameShape(QFrame::Shape::Box);
+    devFrame->setMinimumWidth(550);
+    devFrame->setMaximumWidth(960);
+    devFrame->setMinimumHeight(50);
+    devFrame->setMaximumHeight(50);
 
-//        devWidget->setFixedHeight(50);
-    devWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-    QHBoxLayout * devHorLayout = new QHBoxLayout(devWidget);
+//  devFrame->setFixedHeight(50);
+//  devFrame->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
+    QHBoxLayout * devHorLayout = new QHBoxLayout(devFrame);
     devHorLayout->setSpacing(8);
     devHorLayout->setContentsMargins(16, 0, 0, 0);
 
-    QLabel * iconLabel = new QLabel(devWidget);
+    QLabel * iconLabel = new QLabel(devFrame);
     QSizePolicy iconSizePolicy = iconLabel->sizePolicy();
     iconSizePolicy.setHorizontalPolicy(QSizePolicy::Fixed);
     iconSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
@@ -164,81 +166,57 @@ void NetConnect::rebuildNetStatusComponent(QString iconPath, QString netName){
     iconLabel->setScaledContents(true);
     iconLabel->setPixmap(QPixmap(iconPath));
 
-    QLabel * nameLabel = new QLabel(devWidget);
+    QLabel * nameLabel = new QLabel(devFrame);
     QSizePolicy nameSizePolicy = nameLabel->sizePolicy();
     nameSizePolicy.setHorizontalPolicy(QSizePolicy::Fixed);
     nameSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
     nameLabel->setSizePolicy(nameSizePolicy);
     nameLabel->setScaledContents(true);
-    nameLabel->setText(netName);
+    if ("No Net" != netName) {
+        nameLabel->setText(netName);
+    }
 
-
-    QLabel * statusLabel = new QLabel(devWidget);
+    QLabel * statusLabel = new QLabel(devFrame);
     QSizePolicy statusSizePolicy = statusLabel->sizePolicy();
     statusSizePolicy.setHorizontalPolicy(QSizePolicy::Fixed);
     statusSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
     statusLabel->setSizePolicy(statusSizePolicy);
     statusLabel->setScaledContents(true);
-    statusLabel->setText(tr("connected"));
+    if ("No Net" != netName) {
+        statusLabel->setText(tr("connected"));
+    } else {
+        statusLabel->setText(tr("No network"));
+    }
+
 
     devHorLayout->addWidget(iconLabel);
     devHorLayout->addWidget(nameLabel);
     devHorLayout->addWidget(statusLabel);
     devHorLayout->addStretch();
 
-    devWidget->setLayout(devHorLayout);
+    devFrame->setLayout(devHorLayout);
 
-    baseVerLayout->addWidget(devWidget);
+    baseVerLayout->addWidget(devFrame);
     baseVerLayout->addStretch();
 
     baseWidget->setLayout(baseVerLayout);
 
-    QListWidgetItem * item = new QListWidgetItem(ui->statusListWidget);
-    item->setSizeHint(QSize(502, 52));
-
-    ui->statusListWidget->setItemWidget(item, baseWidget);
+    ui->statusLayout->addWidget(baseWidget);
 }
 
-void NetConnect::_acquireCardInfo(){
-    QList<QNetworkInterface> network = QNetworkInterface::allInterfaces();
-    for (QList<QNetworkInterface>::const_iterator it = network.constBegin(); it != network.constEnd(); it++){
-        CardInfo ci;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
-        if ((*it).type() == QNetworkInterface::Loopback)
-            continue;
-
-        if ((*it).type() == QNetworkInterface::Ethernet)
-            ci.type = ETHERNET;
-        else if ((*it).type() == QNetworkInterface::Wifi)
-            ci.type = WIFI;
-#else
-        if ((*it).flags().testFlag(QNetworkInterface::IsLoopBack))
-            continue;
-       ci.type =ETHERNET;
-#endif
-        ci.name = (*it).humanReadableName();
-
-        QList<QNetworkAddressEntry> addressList = (*it).addressEntries();
-        if (addressList.count() == 0)
-            ci.status = false;
-        else
-            ci.status = true;
-
-        cardinfoQList.append(ci);
-    }
-}
-
-
 void NetConnect::getNetList() {
-    ui->availableListWidget->clear();
-    ui->statusListWidget->clear();
+
+    bool wifiSt = getwifiisEnable();
+    if (!wifiSt) {
+        wifiBtn->setChecked(wifiSt);
+    }
+    wifiBtn->setEnabled(wifiSt);
 
     this->TlanList =  execGetLanList();
     pThread = new QThread;
     pNetWorker = new NetconnectWork;
 
     connect(pNetWorker, &NetconnectWork::wifiGerneral,this,[&](QStringList list){
-
         this->TwifiList = list;
         getWifiListDone(this->TwifiList, this->TlanList);
         QMap<QString, int>::iterator iter = this->wifiList.begin();
@@ -247,39 +225,33 @@ void NetConnect::getNetList() {
             if (!wifiBtn->isChecked()){
                 break;
             }
-            iconamePah= ":/img/plugins/netconnect/wifi" + QString::number(iter.value())+".png";
+            iconamePah= ":/img/plugins/netconnect/wifi" + QString::number(iter.value())+".svg";
             rebuildAvailComponent(iconamePah , iter.key());
             iter++;
         }
 
         for(int i = 0; i < this->lanList.length(); i++) {        ;
-            iconamePah= ":/img/plugins/netconnect/eth.png";
+            iconamePah= ":/img/plugins/netconnect/eth.svg";
             rebuildAvailComponent(iconamePah , lanList.at(i));
         }
 
     });
-    connect(pNetWorker, &NetconnectWork::workerComplete, [=]{
+    connect(pNetWorker, &NetconnectWork::workerComplete,this, [=]{
        pThread->quit();
        pThread->wait();
     });
     pNetWorker->moveToThread(pThread);
     connect(pThread, &QThread::started, pNetWorker, &NetconnectWork::run);
     connect(pThread, &QThread::finished, this, [=]{
+        bool wifiSt = getwifiisEnable();
+        wifiBtn->setEnabled(wifiSt);
+        ui->RefreshBtn->setEnabled(true);
 
+        ui->waitLabel->setVisible(false);
+        ui->statuswaitLabel->setVisible(false);
     });
+    connect(pThread, &QThread::finished, pNetWorker, &NetconnectWork::deleteLater);
     pThread->start();
-
-//    QMap<QString, int>::iterator iter = this->wifiList.begin();
-//    while(iter != this->wifiList.end()) {
-//        iconamePah= ":/img/plugins/netconnect/wifi" + QString::number(iter.value())+".png";
-//        rebuildAvailComponent(iconamePah , iter.key());
-//        iter++;
-//    }
-
-//    for(int i = 0; i < lanList.length(); i++) {        ;
-//        iconamePah= ":/img/plugins/netconnect/eth.png";
-//        rebuildAvailComponent(iconamePah , lanList.at(i));
-//    }
 }
 
 void NetConnect::rebuildAvailComponent(QString iconPath, QString netName){
@@ -292,19 +264,20 @@ void NetConnect::rebuildAvailComponent(QString iconPath, QString netName){
     baseVerLayout->setSpacing(0);
     baseVerLayout->setContentsMargins(0, 0, 0, 2);
 
-    QWidget * devWidget = new QWidget(baseWidget);
-    devWidget->setMinimumWidth(550);
-    devWidget->setMaximumWidth(960);
-    devWidget->setMinimumHeight(50);
-    devWidget->setMaximumHeight(50);
+    QFrame * devFrame = new QFrame(baseWidget);
+    devFrame->setFrameShape(QFrame::Shape::Box);
+    devFrame->setMinimumWidth(550);
+    devFrame->setMaximumWidth(960);
+    devFrame->setMinimumHeight(50);
+    devFrame->setMaximumHeight(50);
 
-//        devWidget->setFixedHeight(50);
-    devWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-    QHBoxLayout * devHorLayout = new QHBoxLayout(devWidget);
+//        devFrame->setFixedHeight(50);
+//    devFrame->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
+    QHBoxLayout * devHorLayout = new QHBoxLayout(devFrame);
     devHorLayout->setSpacing(8);
     devHorLayout->setContentsMargins(16, 0, 0, 0);
 
-    QLabel * iconLabel = new QLabel(devWidget);
+    QLabel * iconLabel = new QLabel(devFrame);
     QSizePolicy iconSizePolicy = iconLabel->sizePolicy();
     iconSizePolicy.setHorizontalPolicy(QSizePolicy::Fixed);
     iconSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
@@ -312,7 +285,7 @@ void NetConnect::rebuildAvailComponent(QString iconPath, QString netName){
     iconLabel->setScaledContents(true);
     iconLabel->setPixmap(QPixmap(iconPath));
 
-    QLabel * nameLabel = new QLabel(devWidget);
+    QLabel * nameLabel = new QLabel(devFrame);
     QSizePolicy nameSizePolicy = nameLabel->sizePolicy();
     nameSizePolicy.setHorizontalPolicy(QSizePolicy::Fixed);
     nameSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
@@ -320,7 +293,7 @@ void NetConnect::rebuildAvailComponent(QString iconPath, QString netName){
     nameLabel->setScaledContents(true);
     nameLabel->setText(netName);
 
-//    QLabel * statusLabel = new QLabel(devWidget);
+//    QLabel * statusLabel = new QLabel(devFrame);
 //    QSizePolicy statusSizePolicy = statusLabel->sizePolicy();
 //    statusSizePolicy.setHorizontalPolicy(QSizePolicy::Fixed);
 //    statusSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
@@ -333,17 +306,14 @@ void NetConnect::rebuildAvailComponent(QString iconPath, QString netName){
 //    devHorLayout->addWidget(statusLabel);
     devHorLayout->addStretch();
 
-    devWidget->setLayout(devHorLayout);
+    devFrame->setLayout(devHorLayout);
 
-    baseVerLayout->addWidget(devWidget);
-    baseVerLayout->addStretch();
+    baseVerLayout->addWidget(devFrame);
+//    baseVerLayout->addStretch();
 
-    baseWidget->setLayout(baseVerLayout);
+//    baseWidget->setLayout(baseVerLayout);
 
-    QListWidgetItem * item = new QListWidgetItem(ui->availableListWidget);
-    item->setSizeHint(QSize(502, 52));
-
-    ui->availableListWidget->setItemWidget(item, baseWidget);
+    ui->availableLayout->addWidget(baseWidget);
 }
 
 
@@ -353,6 +323,39 @@ void NetConnect::runExternalApp(){
     process.startDetached(cmd);
 }
 
+bool NetConnect::getwifiisEnable()
+{
+    QDBusInterface m_interface( "org.freedesktop.NetworkManager",
+                                "/org/freedesktop/NetworkManager",
+                                "org.freedesktop.NetworkManager",
+                                QDBusConnection::systemBus() );
+
+    QDBusReply<QList<QDBusObjectPath>> obj_reply = m_interface.call("GetAllDevices");
+    if (!obj_reply.isValid()) {
+        qDebug()<<"execute dbus method 'GetAllDevices' is invalid in func getObjectPath()";
+    }
+
+    QList<QDBusObjectPath> obj_paths = obj_reply.value();
+
+    foreach (QDBusObjectPath obj_path, obj_paths){
+        QDBusInterface interface( "org.freedesktop.NetworkManager",
+                                  obj_path.path(),
+                                  "org.freedesktop.DBus.Introspectable",
+                                  QDBusConnection::systemBus() );
+
+        QDBusReply<QString> reply = interface.call("Introspect");
+        if (!reply.isValid()) {
+            qDebug()<<"execute dbus method 'Introspect' is invalid in func getObjectPath()";
+        }
+
+        if(reply.value().indexOf("org.freedesktop.NetworkManager.Device.Wired") != -1){
+        } else if (reply.value().indexOf("org.freedesktop.NetworkManager.Device.Wireless") != -1){
+            return true;
+        }
+    }
+    return false ;
+}
+
 
 QStringList NetConnect::execGetLanList(){
     QProcess *lanPro = new QProcess();
@@ -365,36 +368,27 @@ QStringList NetConnect::execGetLanList(){
 
 //    qDebug()<<"lanslist--------------->"<<slist<<endl;
     return slist;
-
-}
-
-QStringList NetConnect::execGetWifiList(){
-    QProcess *wifiPro = new QProcess();
-    QString shellOutput = "";
-    wifiPro->start("nmcli -f signal,ssid device wifi");
-    wifiPro->waitForFinished();
-    QString output = wifiPro->readAll();
-    shellOutput += output;
-    QStringList slist = shellOutput.split("\n");
-
-//    emit getWifiListFinished(slist);
-//    qDebug()<<"wifilist--------------->"<<slist<<endl;
-    return slist;
 }
 
 void NetConnect::getWifiListDone(QStringList getwifislist, QStringList getlanList) {
 
+//    qDebug()<<"getwifiListDone--------->"<<getwifislist<<" \n" <<getlanList<<endl;
+    clearContent();
+
+    QString lockPath = QDir::homePath() + "/.config/control-center-net";
+    activecon *act = kylin_network_get_activecon_info(lockPath.toUtf8().data());
+
     //if is wifi list
     if(!getwifislist.isEmpty()){
         connectedWifi.clear();
         wifiList.clear();
 
         QString actWifiName = "--";
-        activecon *act = kylin_network_get_activecon_info();
+
 
         int index = 0;
         while(act[index].con_name != NULL){
-            if(QString(act[index].type) == "wifi"){
+            if(QString(act[index].type) == "wifi" ||QString(act[index].type) == "802-11-wireless"){
                 actWifiName = QString(act[index].con_name);
                 break;
             }
@@ -438,12 +432,11 @@ void NetConnect::getWifiListDone(QStringList getwifislist, QStringList getlanLis
         lanList.clear();
         connectedLan.clear();
 
-        // 获取当前连接的lan name
-        activecon *actLan = kylin_network_get_activecon_info();
+//        qDebug()<<"the net type is----->"<<actLan[0].type<<endl;
         int indexLan = 0;
-        while(actLan[indexLan].con_name != NULL){
-            if(QString(actLan[indexLan].type) == "ethernet"){
-                actLanName = QString(actLan[indexLan].con_name);
+        while(act[indexLan].con_name != NULL){
+            if (QString(act[indexLan].type) == "ethernet" || QString(act[indexLan].type) == "802-3-ethernet"){
+                actLanName = QString(act[indexLan].con_name);
                 break;
             }
             indexLan ++;
@@ -451,17 +444,25 @@ void NetConnect::getWifiListDone(QStringList getwifislist, QStringList getlanLis
 //        qDebug()<<"actLanName is-------->"<<this->actLanName<<endl;
 
         // 填充可用网络列表
-        QString lanheadLine = getlanList.at(0);
-        lanheadLine = lanheadLine.trimmed();
-        int lanindexDevice = lanheadLine.indexOf("DEVICE");
-        int lanindexName = lanheadLine.indexOf("NAME");
+        QString headLine = getlanList.at(0);
+        int indexDevice, indexName;
+        headLine = headLine.trimmed();
+
+        bool isChineseExist = headLine.contains(QRegExp("[\\x4e00-\\x9fa5]+"));
+        if (isChineseExist) {
+            indexDevice = headLine.indexOf("设备") + 2;
+            indexName = headLine.indexOf("名称") + 4;
+        } else {
+            indexDevice = headLine.indexOf("DEVICE");
+            indexName = headLine.indexOf("NAME");
+    }
 
     //    qDebug()<<"getlanList-------------->"<<getlanList<<endl;
         for(int i =1 ;i < getlanList.length(); i++)
         {
             QString line = getlanList.at(i);
-            QString ltype = line.mid(0, lanindexDevice).trimmed();
-            QString nname = line.mid(lanindexName).trimmed();
+            QString ltype = line.mid(0, indexDevice).trimmed();
+            QString nname = line.mid(indexName).trimmed();
             if(ltype  != "wifi" && ltype != "" && ltype != "--"){
                 this->lanList << nname;
             }
@@ -471,15 +472,19 @@ void NetConnect::getWifiListDone(QStringList getwifislist, QStringList getlanLis
 
     if (!this->connectedWifi.isEmpty()){
         QMap<QString, int>::iterator iter = this->connectedWifi.begin();
-        QString iconamePah = ":/img/plugins/netconnect/wifi" + QString::number(iter.value())+".png";
+        QString iconamePah = ":/img/plugins/netconnect/wifi" + QString::number(iter.value())+".svg";
 //        qDebug()<<"name is=------------>"<<iter.key();
         rebuildNetStatusComponent(iconamePah , iter.key());
     }
     if (!this->actLanName.isEmpty()){
-        QString lanIconamePah= ":/img/plugins/netconnect/eth.png";
+        QString lanIconamePah= ":/img/plugins/netconnect/eth.svg";
         rebuildNetStatusComponent(lanIconamePah, this->actLanName);
 //        qDebug()<<"name is=------------>"<<this->actLanName;
     }
+
+    if (this->connectedWifi.isEmpty() && this->actLanName.isEmpty())  {
+        rebuildNetStatusComponent(":/img/plugins/netconnect/nonet.svg" , "No Net");
+    }
 }
 
 bool NetConnect::getSwitchStatus(QString key){
@@ -495,6 +500,57 @@ bool NetConnect::getSwitchStatus(QString key){
     return res;
 }
 
+bool NetConnect::getInitStatus()
+{
+
+    QDBusInterface interface( "org.freedesktop.NetworkManager",
+                              "/org/freedesktop/NetworkManager",
+                              "org.freedesktop.DBus.Properties",
+                              QDBusConnection::systemBus() );
+    //获取当前wifi是否连接
+    QDBusReply<QVariant> m_result = interface.call("Get", "org.freedesktop.NetworkManager", "WirelessEnabled");
+
+    if (m_result.isValid()){
+        bool status = m_result.value().toBool();
+        return status;
+    } else {
+        qDebug()<<"org.freedesktop.NetworkManager get invalid"<<endl;
+        return false;
+    }
+}
+
+void NetConnect::clearContent()
+{
+    if (ui->availableLayout->layout() != NULL) {
+        QLayoutItem* item;
+        while ((item = ui->availableLayout->layout()->takeAt( 0 )) != NULL )
+        {
+            delete item->widget();
+            delete item;
+        }
+//        delete ui->availableLayout->layout();
+    }
+
+    if (ui->statusLayout->layout() != NULL) {
+        QLayoutItem* item;
+        while ((item = ui->statusLayout->layout()->takeAt( 0 )) != NULL )
+        {
+            delete item->widget();
+            delete item;
+        }
+//        delete ui->availableLayout->layout();
+    }
+//    ui->statusListWidget->clear();
+
+    this->connectedLan.clear();
+    this->connectedWifi.clear();
+    this->actLanName.clear();
+    this->wifiList.clear();
+    this->lanList.clear();
+    this->TlanList.clear();
+    this->TwifiList.clear();
+}
+
 //get wifi's strength
 int NetConnect::setSignal(QString lv) {
     int signal = lv.toInt();
@@ -521,8 +577,6 @@ int NetConnect::setSignal(QString lv) {
 }
 
 void NetConnect::wifiSwitchSlot(bool signal){
-    getNetList();
-//    qDebug()<<"wifiSwitchSlot--------------->"<<endl;
     if(!m_gsettings) {
         return ;
     }
@@ -531,7 +585,8 @@ void NetConnect::wifiSwitchSlot(bool signal){
         return ;
     }
     m_gsettings->set("switch",signal);
+
+    QTimer::singleShot(2*1000,this,SLOT(getNetList()));
 }
 
 
-
