@@ -39,9 +39,12 @@
 #define TITLEBAR_FONT_KEY "titlebar-font" //描述窗口标题栏字体的字符串。只有在"titlebar-uses-system-font"为false时有效
 
 
-#define PEONY_SCHEMA "org.ukui.style"
-#define PEONY_FONT_KEY "system-font"  //桌面上图标描述所用的字体
-#define PEONY_FONT_SIZE_KEY "system-font-size"
+//#define PEONY_SCHEMA "org.ukui.peony.desktop"
+//#define PEONY_FONT_KEY "font"  //桌面上图标描述所用的字体
+
+#define STYLE_FONT_SCHEMA "org.ukui.style"
+#define SYSTEM_FONT_EKY "system-font-size"
+#define SYSTEM_NAME_KEY "system-font"
 
 #define FONT_RENDER_SCHEMA           "org.ukui.font-rendering"
 #define ANTIALIASING_KEY        "antialiasing" //绘制字形时使用反锯齿类型
@@ -60,12 +63,12 @@ struct _FontInfo{
     QString gtkfont;
     QString docfont;
     QString monospacefont;
-    QString peonyfont;
+//    QString peonyfont;
     QString titlebarfont;
     int gtkfontsize;
     int docfontsize;
     int monospacefontsize;
-    int peonyfontsize;
+//    int peonyfontsize;
     int titlebarfontsize;
 };
 
@@ -85,40 +88,48 @@ typedef enum{
     HINT_FULL
 }Hinting;
 
-struct FontEffects : QObjectUserData {
+struct FontEffects{
     Antialiasing antial;
     Hinting hinting;
 };
 
+Q_DECLARE_METATYPE(FontEffects)
+
 QList<int> defaultsizeList = {6, 7, 8, 9, 10, 11, 12, 14, 16, 18, 20, 22, 24, 26, 28, 36, 48, 72};
 
 Fonts::Fonts()
 {
     ui = new Ui::Fonts;
-    itemDelege = new QStyledItemDelegate();
     pluginWidget = new QWidget;
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("fonts");
+    pluginName = tr("Fonts");
     pluginType = PERSONALIZED;
 
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
     settingsCreate = false;
 
     setupStylesheet();
 
+
+    //    const QByteArray iddd(PEONY_SCHEMA);
+    //    peonysettings = new QGSettings(iddd);
+
+    const QByteArray styleID(STYLE_FONT_SCHEMA);
     const QByteArray id(INTERFACE_SCHEMA);
     const QByteArray idd(MARCO_SCHEMA);
     const QByteArray iid(FONT_RENDER_SCHEMA);
-    const QByteArray iddd(PEONY_SCHEMA);
 
-    if (QGSettings::isSchemaInstalled(id) && QGSettings::isSchemaInstalled(iid) &&
-            QGSettings::isSchemaInstalled(idd) && QGSettings::isSchemaInstalled(iddd)){
+    if (QGSettings::isSchemaInstalled(id) && QGSettings::isSchemaInstalled(iid) && QGSettings::isSchemaInstalled(idd) &&
+            QGSettings::isSchemaInstalled(styleID)){
         settingsCreate = true;
         marcosettings = new QGSettings(idd);
         ifsettings = new QGSettings(id);
         rendersettings = new QGSettings(iid);
-        peonysettings = new QGSettings(iddd);
+        stylesettings = new QGSettings(styleID);
+
         _getDefaultFontinfo();
         setupComponent();
         setupConnect();
@@ -133,8 +144,9 @@ Fonts::~Fonts()
     if (settingsCreate){
         delete ifsettings;
         delete marcosettings;
-        delete peonysettings;
+    //    delete peonysettings;
         delete rendersettings;
+        delete stylesettings;
     }
 
 }
@@ -156,84 +168,70 @@ void Fonts::plugin_delay_control(){
 }
 
 void Fonts::setupStylesheet(){
-    pluginWidget->setStyleSheet("background: #ffffff;");
-    ui->fontSizeWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 4px;}");
+
+
+
+    ui->titleSecondLabel->setVisible(false);
+    ui->sampleBtn1->setVisible(false);
+    ui->sampleBtn2->setVisible(false);
+    ui->sampleBtn3->setVisible(false);
+    ui->sampleBtn4->setVisible(false);
+
+//    pluginWidget->setStyleSheet("background: #ffffff;");
+//    ui->fontSizeWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 4px;}");
 //    ui->fontSizeLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
 
-    ui->fontTypeWidget->setStyleSheet("QWidget#fontTypeWidget{background: #F4F4F4; border-radius: 4px;}");
-    ui->fontSelectLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
-    ui->monoSelectLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->fontTypeWidget->setStyleSheet("QWidget#fontTypeWidget{background: #F4F4F4; border-radius: 4px;}");
+//    ui->fontSelectLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->monoSelectLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
 
-    ui->fontSizeSlider->setStyleSheet("QSlider{height: 20px;}"
-                                      "QSlider::groove:horizontal{border: none;}"
-                                      "QSlider::add-page:horizontal{background: #808080; border-radius: 2px; margin-top: 8px; margin-bottom: 9px;}"
-                                      "QSlider::sub-page:horizontal{background: #3D6BE5; border-radius: 2px; margin-top: 8px; margin-bottom: 9px;}"
-                                      "QSlider::handle:horizontal{width: 20px; height: 20px; border-image: url(:/img/plugins/fonts/bigRoller.png);}"
-                                      "");
+//    ui->fontSizeSlider->setStyleSheet("QSlider{height: 20px;}"
+//                                      "QSlider::groove:horizontal{border: none;}"
+//                                      "QSlider::add-page:horizontal{background: #808080; border-radius: 2px; margin-top: 8px; margin-bottom: 9px;}"
+//                                      "QSlider::sub-page:horizontal{background: #3D6BE5; border-radius: 2px; margin-top: 8px; margin-bottom: 9px;}"
+//                                      "QSlider::handle:horizontal{width: 20px; height: 20px; border-image: url(:/img/plugins/fonts/bigRoller.png);}"
+//                                      "");
 
 
-    ui->advancedBtn->setStyleSheet("QPushButton#advancedBtn{background: #F4F4F4; border: none; border-radius: 4px;}");
+//    ui->advancedBtn->setStyleSheet("QPushButton#advancedBtn{background: #F4F4F4; border: none; border-radius: 4px;}");
 
-    ui->advancedWidget->setStyleSheet("QWidget#advancedWidget{background: #F4F4F4; border-radius: 4px;}");
-    ui->defaultFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
-    ui->monoFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
-    ui->docFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
-    ui->peonyFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
-    ui->titleFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->advancedWidget->setStyleSheet("QWidget#advancedWidget{background: #F4F4F4; border-radius: 4px;}");
+//    ui->defaultFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->monoFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->docFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->peonyFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->titleFontLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
 
 
-    ui->sampleBtn1->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
-                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
-    ui->sampleBtn2->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
-                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
-    ui->sampleBtn3->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
-                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
-    ui->sampleBtn4->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
-                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
+//    ui->sampleBtn1->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
+//                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
+//    ui->sampleBtn2->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
+//                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
+//    ui->sampleBtn3->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
+//                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
+//    ui->sampleBtn4->setStyleSheet("QPushButton{background: #F0F0F0; border-radius: 4px;}"
+//                                  "QPushButton:checked{background: #F0F3FD; border-radius: 4px;}");
 }
 
 void Fonts::setupComponent(){
-    ui->fontSelectComBox->setItemDelegate(itemDelege);
-    ui->fontSelectComBox->setMaxVisibleItems(5);
 
-    ui->monoSelectComBox->setItemDelegate(itemDelege);
-    ui->monoSelectComBox->setMaxVisibleItems(5);
+    QStringList fontScale;
+    fontScale<< tr("11") << tr("12") << tr("13") << tr("14") << tr("15")
+              <<tr("16") << tr("17") << tr("18");
 
-    ui->defaultFontComBox->setItemDelegate(itemDelege);
-    ui->defaultFontComBox->setMaxVisibleItems(5);
+    uslider  = new Uslider(fontScale);
+    uslider->setRange(1,8);
+    uslider->setTickInterval(1);
+    uslider->setPageStep(1);
 
-    ui->docFontComBox->setItemDelegate(itemDelege);
-    ui->docFontComBox->setMaxVisibleItems(5);
-
-    ui->peonyFontComBox->setItemDelegate(itemDelege);
-    ui->peonyFontComBox->setMaxVisibleItems(5);
-
-    ui->monoFontComBox->setItemDelegate(itemDelege);
-    ui->monoFontComBox->setMaxVisibleItems(5);
-
-    ui->titleFontComBox->setItemDelegate(itemDelege);
-    ui->titleFontComBox->setMaxVisibleItems(5);
-
-    ui->defaultSizeComBox->setItemDelegate(itemDelege);
-    ui->defaultSizeComBox->setMaxVisibleItems(5);
-
-    ui->docSizeComBox->setItemDelegate(itemDelege);
-    ui->docSizeComBox->setMaxVisibleItems(5);
-
-    ui->MonoSizeComBox->setItemDelegate(itemDelege);
-    ui->MonoSizeComBox->setMaxVisibleItems(5);
-
-    ui->peonySizeComBox->setItemDelegate(itemDelege);
-    ui->peonySizeComBox->setMaxVisibleItems(5);
-
-    ui->titleSizeComBox->setItemDelegate(itemDelege);
-    ui->titleSizeComBox->setMaxVisibleItems(5);
+    ui->fontLayout->addWidget(uslider);
+    ui->fontLayout->addSpacing(8);
 
 //    ui->fontSizeSlider->setMinimum(100);
 //    ui->fontSizeSlider->setMaximum(275);
 //    ui->fontSizeSlider->setSingleStep(25);
 //    ui->fontSizeSlider->setPageStep(25);
-    ui->fontSizeSlider->setTickPosition(QSlider::TicksBelow);
+//    ui->fontSizeSlider->setTickPosition(QSlider::TicksBelow);
 
     //导入系统字体列表
     QStringList fontfamiles = fontdb.families();
@@ -267,47 +265,55 @@ void Fonts::setupComponent(){
     QList<int> gtksizeList = fontdb.pointSizes(gtkfontStrList.at(0));
     QList<int> docsizeList = fontdb.pointSizes(docfontStrList.at(0));
     QList<int> monosizeList = fontdb.pointSizes(monospacefontStrList.at(0));
-    QList<int> peonysizeList = fontdb.pointSizes(peonysettings->get(PEONY_FONT_KEY).toString());
+//    QList<int> peonysizeList = fontdb.pointSizes(peonyfontStrList.at(0));
     QList<int> titlesizeList = fontdb.pointSizes(titlebarfontStrList.at(0));
 
     if (gtksizeList.length() == 0)
         gtksizeList = defaultsizeList;
-    for (int size : gtksizeList)
-        ui->defaultSizeComBox->addItem(QString::number(size));
+    for (int size : gtksizeList) {
+        if (size >=11 && size <= 18)
+            ui->defaultSizeComBox->addItem(QString::number(size));
+    }
+
     if (docsizeList.length() == 0)
         docsizeList = defaultsizeList;
-    for (int size : docsizeList)
-        ui->docSizeComBox->addItem(QString::number(size));
+    for (int size : docsizeList) {
+        if (size >=11 && size <= 18)
+            ui->docSizeComBox->addItem(QString::number(size));
+    }
     if (monosizeList.length() == 0)
         monosizeList = defaultsizeList;
-    for (int size : monosizeList)
-        ui->MonoSizeComBox->addItem(QString::number(size));
-    if (peonysizeList.length() == 0)
-        peonysizeList = defaultsizeList;
-    for (int size : peonysizeList)
-        ui->peonySizeComBox->addItem(QString::number(size));
+    for (int size : monosizeList) {
+        if (size >=11 && size <= 18)
+            ui->MonoSizeComBox->addItem(QString::number(size));
+    }
+//    if (peonysizeList.length() == 0)
+//        peonysizeList = defaultsizeList;
+//    for (int size : peonysizeList)
+//        ui->peonySizeComBox->addItem(QString::number(size));
     if (titlesizeList.length() == 0)
         titlesizeList = defaultsizeList;
-    for (int size : titlesizeList)
-        ui->titleSizeComBox->addItem(QString::number(size));
-
+    for (int size : titlesizeList) {
+        if (size >=11 && size <= 18)
+            ui->titleSizeComBox->addItem(QString::number(size));
+    }
     //设置高级配置是否显示
-    ui->advancedWidget->setVisible(ui->advancedBtn->isChecked());
+    ui->advancedFrame->setVisible(ui->advancedBtn->isChecked());
 
     //init sample button
-    FontEffects * example1 = new FontEffects();
-    FontEffects * example2 = new FontEffects();
-    FontEffects * example3 = new FontEffects();
-    FontEffects * example4 = new FontEffects();
-    example1->antial = ANTIALIASING_NONE; example1->hinting = HINT_FULL;
-    example2->antial = ANTIALIASING_GRAYSCALE; example2->hinting = HINT_FULL;
-    example3->antial = ANTIALIASING_GRAYSCALE; example3->hinting = HINT_MEDIUM;
-    example4->antial = ANTIALIASING_RGBA; example4->hinting = HINT_FULL;
+    FontEffects example1;
+    FontEffects example2;
+    FontEffects example3;
+    FontEffects example4;
+    example1.antial = ANTIALIASING_NONE; example1.hinting = HINT_FULL;
+    example2.antial = ANTIALIASING_GRAYSCALE; example2.hinting = HINT_FULL;
+    example3.antial = ANTIALIASING_GRAYSCALE; example3.hinting = HINT_MEDIUM;
+    example4.antial = ANTIALIASING_RGBA; example4.hinting = HINT_FULL;
 
-    ui->sampleBtn1->setUserData(Qt::UserRole, example1);
-    ui->sampleBtn2->setUserData(Qt::UserRole, example2);
-    ui->sampleBtn3->setUserData(Qt::UserRole, example3);
-    ui->sampleBtn4->setUserData(Qt::UserRole, example4);
+    ui->sampleBtn1->setProperty("userData", QVariant::fromValue(example1));
+    ui->sampleBtn2->setProperty("userData", QVariant::fromValue(example2));
+    ui->sampleBtn3->setProperty("userData", QVariant::fromValue(example3));
+    ui->sampleBtn4->setProperty("userData", QVariant::fromValue(example4));
 
 //    setSampleButton(ui->sampleBtn1);
 
@@ -331,8 +337,8 @@ void Fonts::setSampleButton(QPushButton *button){
 }
 
 void Fonts::setupConnect(){
-//    connect(ui->fontSizeSlider, &QSlider::sliderReleased, [=]{
-//        int value = ui->fontSizeSlider->value();
+//    connect(uslider, &QSlider::sliderReleased, [=]{
+//        int value = uslider->value();
 
 //        int setup = value / 25; int overage = value % 25;
 
@@ -341,29 +347,27 @@ void Fonts::setupConnect(){
 //        else
 //            ui->fontSizeSlider->setSliderPosition(ui->fontSizeSlider->singleStep() * setup);
 //    });
-    connect(ui->fontSizeSlider, &QSlider::valueChanged, [=](int value){
+    connect(uslider, &QSlider::valueChanged, [=](int value){
+        int size = sliderConvertToSize(value);
         //获取当前字体信息
         _getCurrentFontInfo();
         //设置字体大小
-        ifsettings->set(GTK_FONT_KEY, QVariant(QString("%1 %2").arg(gtkfontStrList.at(0)).arg(QString::number(value))));
-        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(docfontStrList.at(0)).arg(QString::number(value))));
-        ifsettings->set(MONOSPACE_FONT_KEY, QVariant(QString("%1 %2").arg(monospacefontStrList.at(0)).arg(QString::number(value))));
-        //            peonysettings->set(PEONY_FONT_KEY, QVariant(QString("%1 %2").arg(peonyfontStrList[0]).arg(defaultfontinfo.monospacefontsize * level)));
-        peonysettings->set(PEONY_FONT_SIZE_KEY, QString::number(value));
-        marcosettings->set(TITLEBAR_FONT_KEY, QVariant(QString("%1 %2").arg(titlebarfontStrList.at(0)).arg(QString::number(value))));
-
-        //给更新高级字体配置
-        initAdvancedFontStatus();
 
+        ifsettings->set(GTK_FONT_KEY, QVariant(QString("%1 %2").arg(gtkfontStrList.at(0)).arg(size)));
+        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(docfontStrList.at(0)).arg(size)));
+        ifsettings->set(MONOSPACE_FONT_KEY, QVariant(QString("%1 %2").arg(monospacefontStrList.at(0)).arg(size)));
+        stylesettings->set(SYSTEM_FONT_EKY, QVariant(QString("%1").arg(size)));
+//            peonysettings->set(PEONY_FONT_KEY, QVariant(QString("%1 %2").arg(peonyfontStrList[0]).arg(defaultfontinfo.monospacefontsize * level)));
+        marcosettings->set(TITLEBAR_FONT_KEY, QVariant(QString("%1 %2").arg(titlebarfontStrList.at(0)).arg(size)));
     });
 
     connect(ui->fontSelectComBox, &QComboBox::currentTextChanged, [=](QString text){
         //获取当前字体信息
         _getCurrentFontInfo();
         ifsettings->set(GTK_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(gtkfontStrList.at(1))));
-        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(docfontStrList.at(1))));
+        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(docfontStrList.at(1))));        
 //        peonysettings->set(PEONY_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(peonyfontStrList.at(1))));
-        peonysettings->set(PEONY_FONT_KEY, text);
+        stylesettings->set(SYSTEM_NAME_KEY, QVariant(QString("%1").arg(text)));
         marcosettings->set(TITLEBAR_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(titlebarfontStrList.at(1))));
 
         //给更新高级字体配置
@@ -381,61 +385,55 @@ void Fonts::setupConnect(){
 
     //高级字体按钮状态
     connect(ui->advancedBtn, &QPushButton::clicked, this, [=]{
-        ui->advancedWidget->setVisible(ui->advancedBtn->isChecked());
+        ui->advancedFrame->setVisible(ui->advancedBtn->isChecked());
     });
 
     connect(ui->defaultFontComBox, &QComboBox::currentTextChanged, [=](QString text){
         _getCurrentFontInfo();
-        ifsettings->set(GTK_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(gtkfontStrList.at(1))));
+        ifsettings->set(GTK_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(ui->defaultSizeComBox->currentText())));
     });
-    connect(ui->docFontComBox, &QComboBox::currentTextChanged, [=](QString text){
+    connect(ui->defaultSizeComBox, &QComboBox::currentTextChanged, [=](QString text){
         _getCurrentFontInfo();
-        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(docfontStrList.at(1))));
-    });
-    connect(ui->monoFontComBox, &QComboBox::currentTextChanged, [=](QString text){
-        _getCurrentFontInfo();
-        ifsettings->set(MONOSPACE_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(monospacefontStrList.at(1))));
+        ifsettings->set(GTK_FONT_KEY, QVariant(QString("%1 %2").arg(ui->defaultFontComBox->currentText()).arg(text)));
     });
 
-    connect(ui->peonyFontComBox, &QComboBox::currentTextChanged, [=](QString text){
-        peonysettings->set(PEONY_FONT_KEY, QVariant(text));
+    connect(ui->docFontComBox, &QComboBox::currentTextChanged, [=](QString text){
+        _getCurrentFontInfo();
+        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(ui->docSizeComBox->currentText())));
+    });
+    connect(ui->docSizeComBox, &QComboBox::currentTextChanged, [=](QString text){
+        _getCurrentFontInfo();
+        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(ui->docFontComBox->currentText()).arg(text)));
+    });
+
+    connect(ui->monoFontComBox, &QComboBox::currentTextChanged, [=](QString text){
+        _getCurrentFontInfo();
+        ifsettings->set(MONOSPACE_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(ui->MonoSizeComBox->currentText())));
+        initGeneralFontStatus();
+    });
+    connect(ui->MonoSizeComBox, &QComboBox::currentTextChanged, [=](QString text){
+        _getCurrentFontInfo();
+        ifsettings->set(MONOSPACE_FONT_KEY, QVariant(QString("%1 %2").arg(ui->monoFontComBox->currentText()).arg(text)));
     });
 
     connect(ui->titleFontComBox, &QComboBox::currentTextChanged, [=](QString text){
         _getCurrentFontInfo();
-        marcosettings->set(TITLEBAR_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(titlebarfontStrList.at(1))));
+        marcosettings->set(TITLEBAR_FONT_KEY, QVariant(QString("%1 %2").arg(text).arg(ui->titleSizeComBox->currentText())));
     });
-
-    connect(ui->defaultSizeComBox, &QComboBox::currentTextChanged, [=](QString text){
-        _getCurrentFontInfo();
-        ifsettings->set(GTK_FONT_KEY, QVariant(QString("%1 %2").arg(gtkfontStrList.at(0)).arg(text)));
-    });
-
-    connect(ui->docSizeComBox, &QComboBox::currentTextChanged, [=](QString text){
-        _getCurrentFontInfo();
-        ifsettings->set(DOC_FONT_KEY, QVariant(QString("%1 %2").arg(docfontStrList.at(0)).arg(text)));
-    });
-
     connect(ui->titleSizeComBox, &QComboBox::currentTextChanged, [=](QString text){
         _getCurrentFontInfo();
-        marcosettings->set(TITLEBAR_FONT_KEY, QVariant(QString("%1 %2").arg(titlebarfontStrList.at(0)).arg(text)));
-    });
-
-    connect(ui->peonySizeComBox, &QComboBox::currentTextChanged, [=](QString text){
-        peonysettings->set(PEONY_FONT_SIZE_KEY, QVariant(text));
-    });
-
-    connect(ui->MonoSizeComBox, &QComboBox::currentTextChanged, [=](QString text){
-        _getCurrentFontInfo();
-        ifsettings->set(MONOSPACE_FONT_KEY, QVariant(QString("%1 %2").arg(monospacefontStrList.at(0)).arg(text)));
+        marcosettings->set(TITLEBAR_FONT_KEY, QVariant(QString("%1 %2").arg(ui->titleFontComBox->currentText()).arg(text)));
     });
 
     ////绑定信号
     //字体效果按钮
+#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
+    connect(ui->sampleBtnGroup, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), [=](QAbstractButton * button){
+#else
     connect(ui->sampleBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), [=](QAbstractButton * button){
+#endif
         setFontEffect(button);
     });
-
     //重置按钮
     connect(ui->resetBtn, &QPushButton::clicked, [=](bool checked){
         Q_UNUSED(checked)
@@ -466,6 +464,9 @@ void Fonts::initGeneralFontStatus(){
 
     //初始化等宽字体ComBox
     QString currentmonofont = monospacefontStrList[0];
+    if ("DejaVu sans Mono" == currentmonofont) {
+        currentmonofont = "DejaVu Sans Mono";
+    }
     ui->monoSelectComBox->blockSignals(true);
     ui->monoSelectComBox->setCurrentText(currentmonofont);
     ui->monoSelectComBox->blockSignals(false);
@@ -473,13 +474,14 @@ void Fonts::initGeneralFontStatus(){
     //获取字体大小倍率,选择文档字体大小作为标准，来自gtk控制面板的逻辑
 //    float res = QString(docfontStrList[1]).toFloat() / (float)defaultfontinfo.docfontsize;
 //    int value = int(res * 100);
-    int value = QString(docfontStrList.at(1)).toInt();
 
-    ui->fontSizeSlider->blockSignals(true);
+    int size = fontConvertToSlider(QString(docfontStrList[1]).toInt());
 
-    ui->fontSizeSlider->setValue(value);
+    uslider->blockSignals(true);
 
-    ui->fontSizeSlider->blockSignals(false);
+    uslider->setValue(size);
+
+    uslider->blockSignals(false);
 
 }
 
@@ -491,41 +493,47 @@ void Fonts::initAdvancedFontStatus(){
     ui->defaultFontComBox->blockSignals(true);
     ui->docFontComBox->blockSignals(true);
     ui->monoFontComBox->blockSignals(true);
-    ui->peonyFontComBox->blockSignals(true);
+//    ui->peonyFontComBox->blockSignals(true);
     ui->titleFontComBox->blockSignals(true);
 
     //初始化高级字体ComBox
     ui->defaultFontComBox->setCurrentText(gtkfontStrList.at(0));
     ui->docFontComBox->setCurrentText(docfontStrList.at(0));
-    ui->monoFontComBox->setCurrentText(monospacefontStrList.at(0));
-    ui->peonyFontComBox->setCurrentText(peonysettings->get(PEONY_FONT_KEY).toString());
+
+
+    QString currentmonofont = monospacefontStrList.at(0);
+    if ("DejaVu sans Mono" == currentmonofont) {
+        currentmonofont = "DejaVu Sans Mono";
+    }
+    ui->monoFontComBox->setCurrentText(currentmonofont);
+//    ui->peonyFontComBox->setCurrentText(peonyfontStrList.at(0));
     ui->titleFontComBox->setCurrentText(titlebarfontStrList.at(0));
 
     //释放信号
     ui->defaultFontComBox->blockSignals(false);
     ui->docFontComBox->blockSignals(false);
     ui->monoFontComBox->blockSignals(false);
-    ui->peonyFontComBox->blockSignals(false);
+//    ui->peonyFontComBox->blockSignals(false);
     ui->titleFontComBox->blockSignals(false);
 
     //阻塞字体大小ComBox信号
     ui->defaultSizeComBox->blockSignals(true);
     ui->docSizeComBox->blockSignals(true);
     ui->MonoSizeComBox->blockSignals(true);
-    ui->peonySizeComBox->blockSignals(true);
+//    ui->peonySizeComBox->blockSignals(true);
     ui->titleSizeComBox->blockSignals(true);
 
     ui->defaultSizeComBox->setCurrentText(gtkfontStrList.at(1));
     ui->docSizeComBox->setCurrentText(docfontStrList.at(1));
     ui->MonoSizeComBox->setCurrentText(monospacefontStrList.at(1));
-    ui->peonySizeComBox->setCurrentText(peonysettings->get(PEONY_FONT_SIZE_KEY).toString());
+//    ui->peonySizeComBox->setCurrentText(peonyfontStrList.at(1));
     ui->titleSizeComBox->setCurrentText(titlebarfontStrList.at(1));
 
     //阻塞字体大小ComBox信号
     ui->defaultSizeComBox->blockSignals(false);
     ui->docSizeComBox->blockSignals(false);
     ui->MonoSizeComBox->blockSignals(false);
-    ui->peonySizeComBox->blockSignals(false);
+//    ui->peonySizeComBox->blockSignals(false);
     ui->titleSizeComBox->blockSignals(false);
 
 }
@@ -537,8 +545,8 @@ void Fonts::initSampleFontStatus(){
     int currenthinting = g_settings_get_enum(settings, HINTING_KEY);
     QList<QAbstractButton *> buttonsList = ui->sampleBtnGroup->buttons();
     for (int num = 0; num < buttonsList.size(); num++){
-        FontEffects * btnFontEffects = (FontEffects *)((QPushButton *)buttonsList[num])->userData(Qt::UserRole);
-        if (currentantial == btnFontEffects->antial && currenthinting == btnFontEffects->hinting){
+        FontEffects btnFontEffects = dynamic_cast<QPushButton *>(buttonsList[num])->property("userData").value<FontEffects>();
+        if (currentantial == btnFontEffects.antial && currenthinting == btnFontEffects.hinting){
             QPushButton * button = ((QPushButton *)buttonsList[num]);
             button->blockSignals(true);
             button->setChecked(true);
@@ -590,9 +598,8 @@ void Fonts::_getDefaultFontinfo(){
     g_variant_unref(value);
 
     //PEONY
-    GSettings * peonygsettings;
-    peonygsettings = g_settings_new(PEONY_SCHEMA);
-    defaultfontinfo.peonyfontsize = g_settings_get_int(peonygsettings, PEONY_FONT_SIZE_KEY);
+//    GSettings * peonygsettings;
+//    peonygsettings = g_settings_new(PEONY_SCHEMA);
 //    value = g_settings_get_default_value(peonygsettings, PEONY_FONT_KEY);
 //    size = g_variant_get_size(value);
 //    font_value = g_variant_get_string(value, &size);
@@ -617,7 +624,7 @@ void Fonts::_getDefaultFontinfo(){
     g_variant_unref(value);
 
     g_object_unref(ifgsettings);
-    g_object_unref(peonygsettings);
+//    g_object_unref(peonygsettings);
     g_object_unref(marcogsettings);
 }
 
@@ -631,7 +638,10 @@ void Fonts::_getCurrentFontInfo(){
 
 QStringList Fonts::_splitFontNameSize(QString value){
     QStringList valueStringList;
-    if (value.right(1) >= '0' && value.right(1) <= '9'){
+    QString str = value.right(1);
+    QString ch0 = static_cast<QString>('0');
+    QString ch9 = static_cast<QString>('9');
+    if (str >= ch0 && str <= ch9){
         QStringList tmpStringList = value.split(' ');
         QString::SectionFlag flag = QString::SectionSkipEmpty;
         valueStringList << value.section(' ', 0, tmpStringList.length() - 2, flag);
@@ -643,13 +653,78 @@ QStringList Fonts::_splitFontNameSize(QString value){
     return valueStringList;
 }
 
+int Fonts::fontConvertToSlider(const int size) const
+{
+    switch (size) {
+    case 11:
+        return 1;
+        break;
+    case 12:
+        return 2;
+        break;
+    case 13:
+        return 3;
+        break;
+    case 14:
+        return 4;
+        break;
+    case 15:
+        return 5;
+        break;
+    case 16:
+        return 6;
+        break;
+    case 17:
+        return 7;
+        break;
+    case 18:
+        return 8;
+        break;
+    default:
+        return 1;
+        break;
+    }
+}
+
+int Fonts::sliderConvertToSize(const int value) const
+{
+    switch (value) {
+    case 1:
+        return 11;
+        break;
+    case 2:
+        return 12;
+        break;
+    case 3:
+        return 13;
+        break;
+    case 4:
+        return 14;
+        break;
+    case 5:
+        return 15;
+        break;
+    case 6:
+        return 16;
+        break;
+    case 7:
+        return 17;
+        break;
+    case 8:
+        return 18;
+    default:
+        return 11;
+        break;
+    }
+}
+
 void Fonts::setFontEffect(QAbstractButton *button){
     QPushButton * btnclicked = (QPushButton *)button;
-    FontEffects * setFontEffects = (FontEffects *)(btnclicked->userData(Qt::UserRole));
+    FontEffects setFontEffects = btnclicked->property("userData").value<FontEffects>();
 
     GSettings * settings = g_settings_new(FONT_RENDER_SCHEMA);
-    g_settings_set_enum(settings, ANTIALIASING_KEY, setFontEffects->antial);
-    g_settings_set_enum(settings, HINTING_KEY, setFontEffects->hinting);
+    g_settings_set_enum(settings, ANTIALIASING_KEY, setFontEffects.antial);
+    g_settings_set_enum(settings, HINTING_KEY, setFontEffects.hinting);
     g_object_unref(settings);
 }
 
@@ -658,9 +733,10 @@ void Fonts::resetDefault(){
     ifsettings->reset(GTK_FONT_KEY);
     ifsettings->reset(DOC_FONT_KEY);
     ifsettings->reset(MONOSPACE_FONT_KEY);
-    peonysettings->reset(PEONY_FONT_KEY);
-    peonysettings->reset(PEONY_FONT_SIZE_KEY);
+//    peonysettings->reset(PEONY_FONT_KEY);
     marcosettings->reset(TITLEBAR_FONT_KEY);
+    stylesettings->set(SYSTEM_FONT_EKY, 11);
+    stylesettings->reset(SYSTEM_NAME_KEY);
 
     //reset font render
     rendersettings->reset(ANTIALIASING_KEY);
