@@ -59,34 +59,35 @@ void PreviewWidget::paintEvent(QPaintEvent *e){
 Screensaver::Screensaver()
 {
     ui = new Ui::Screensaver;
-    itemDelege = new QStyledItemDelegate();
     pluginWidget = new QWidget;
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("screensaver");
+    pluginName = tr("Screensaver");
     pluginType = PERSONALIZED;
 
-    pluginWidget->setStyleSheet("background: #ffffff;");
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
+//    pluginWidget->setStyleSheet("background: #ffffff;");
 
     ui->previewWidget->setStyleSheet("#previewWidget{background: black; border-radius: 6px;}");
     ui->previewWidget->setAutoFillBackground(true);
 
-    mPreviewWidget = new PreviewWidget;
-    mPreviewWidget->resize(400,222);
-    QBoxLayout *mPreviewLayout = new QBoxLayout(QBoxLayout::TopToBottom);
-    mPreviewLayout->addWidget(mPreviewWidget);
-    ui->previewWidget->setLayout(mPreviewLayout);
+//    mPreviewWidget = new PreviewWidget;
+//    mPreviewWidget->resize(400,222);
+//    QBoxLayout *mPreviewLayout = new QBoxLayout(QBoxLayout::TopToBottom);
+//    mPreviewLayout->addWidget(mPreviewWidget);
+//    ui->previewWidget->setLayout(mPreviewLayout);
 
-    ui->enableWidget->setStyleSheet("QWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
+//    ui->enableWidget->setStyleSheet("QWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
 
-    ui->programWidget->setStyleSheet("QWidget#programWidget{background: #F4F4F4;}");
-    ui->programLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
+//    ui->programWidget->setStyleSheet("QWidget#programWidget{background: #F4F4F4;}");
+//    ui->programLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
 
-    ui->idleWidget->setStyleSheet("QWidget{background: #F4F4F4; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
-    ui->idleLineEdit->setStyleSheet("QLineEdit{background: #ffffff; border-radius: 0px;}");
+//    ui->idleWidget->setStyleSheet("QWidget{background: #F4F4F4; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
+//    ui->idleLineEdit->setStyleSheet("QLineEdit{background: #ffffff; border-radius: 0px;}");
 
-    ui->lockWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
+//    ui->lockWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
 
     process = new QProcess();
 
@@ -96,16 +97,19 @@ Screensaver::Screensaver()
     initThemeStatus();
     initIdleSliderStatus();
 
-    init_theme_info_map();
-    component_init();
-    status_init();
+//    init_theme_info_map();
+//    component_init();
+//    status_init();
 }
 
 Screensaver::~Screensaver()
 {
     delete ui;
     delete process;
-    process = nullptr;
+    process = nullptr;    
+    if (!screenlock_settings) {
+        delete screenlock_settings;
+    }
 }
 
 QString Screensaver::get_plugin_name(){
@@ -126,71 +130,124 @@ void Screensaver::plugin_delay_control(){
 }
 
 void Screensaver::initComponent(){
+    if (QGSettings::isSchemaInstalled(SCREENSAVER_SCHEMA)) {
+        const QByteArray id(SCREENSAVER_SCHEMA);
+        screenlock_settings = new QGSettings(id);
+
+        connect(screenlock_settings, &QGSettings::changed, [=](QString key) {
+            if (key == "lockEnabled") {
+                bool judge = screenlock_settings->get(LOCK_KEY).toBool();
+                if (judge && !enableSwitchBtn->isChecked()) {
+                    enableSwitchBtn->setChecked(judge);
+                }
+            }
+        });
+    }
+
+    if(QGSettings::isSchemaInstalled(SESSION_SCHEMA)) {
+        qSessionSetting = new QGSettings(SESSION_SCHEMA, QByteArray(), this);
+    }
+
+    if(QGSettings::isSchemaInstalled(SCREENSAVER_SCHEMA)) {
+        qScreenSaverSetting = new QGSettings(SCREENSAVER_SCHEMA, QByteArray(), this);
+    }
+
+    screensaver_bin = "/usr/lib/ukui-screensaver/ukui-screensaver-default";
 
     //添加开启屏保按钮
-    enableSwitchBtn = new SwitchButton(ui->enableWidget);
+    enableSwitchBtn = new SwitchButton(ui->enableFrame);
     ui->enableHorLayout->addStretch();
     ui->enableHorLayout->addWidget(enableSwitchBtn);
 
     //添加锁定屏幕开关按钮
-    lockSwitchBtn = new SwitchButton(ui->lockWidget);
+    lockSwitchBtn = new SwitchButton(ui->lockFrame);
     ui->lockHorLayout->addStretch();
     ui->lockHorLayout->addWidget(lockSwitchBtn);
 
     //初始化屏保程序下拉列表
-    ui->comboBox->setItemDelegate(itemDelege);
-    ui->comboBox->setMaxVisibleItems(5);
     ui->comboBox->addItem(tr("Default_ukui"));
     ui->comboBox->addItem(tr("Blank_Only"));
-    ui->comboBox->addItem(tr("Random"));
+//    ui->comboBox->addItem(tr("Random"));
     QMap<QString, SSThemeInfo>::iterator it = infoMap.begin();
-    for (int index = 3; it != infoMap.end(); it++, index++){
+    for (int index = 2; it != infoMap.end(); it++, index++){
         SSThemeInfo info = (SSThemeInfo)it.value();
         ui->comboBox->addItem(info.name);
         ui->comboBox->setItemData(index, QVariant::fromValue(info));
     }
 
     //初始化滑动条
-    ui->idleSlider->setMinimum(IDLEMIN);
-    ui->idleSlider->setMaximum(IDLEMAX);
-    ui->idleSlider->setSingleStep(IDLESTEP);
-    ui->idleSlider->setPageStep(IDLESTEP);
+    QStringList scaleList;
+    scaleList<< tr("1m") << tr("5m") << tr("10m") << tr("30m") << tr("45m")
+              <<tr("1h") << tr("1.5h") << tr("3h");
 
-    connect(enableSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked){
+    uslider = new Uslider(scaleList);
+    uslider->setRange(1,8);
+    uslider->setTickInterval(1);
+    uslider->setPageStep(1);
+
+    ui->lockhorizontalLayout->addWidget(uslider);
+    ui->lockhorizontalLayout->addSpacing(15);
+
+//    ui->idleSlider->setMinimum(IDLEMIN);
+//    ui->idleSlider->setMaximum(IDLEMAX);
+//    ui->idleSlider->setSingleStep(IDLESTEP);
+//    ui->idleSlider->setPageStep(IDLESTEP);
+
+    connect(enableSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked) {
         screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
         g_settings_set_boolean(screensaver_settings, ACTIVE_KEY, checked);
 
         //刷新LockWidget状态
-        ui->lockWidget->setVisible(checked);
+//        ui->lockFrame->setVisible(checked);
         g_object_unref(screensaver_settings);
     });
 
-    connect(lockSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked){
-        //REVIEW*** g_object_unref faild
-        //    screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
-        //    g_settings_set_boolean(screensaver_settings, LOCK_KEY, status);
-        //    if (screensaver_settings)
-        //            g_object_unref(screensaver_settings);
-        const QByteArray ba(SCREENSAVER_SCHEMA);
-        QGSettings * settings = new QGSettings(ba);
-        settings->set(LOCK_KEY, checked);
-        delete settings;
+    connect(qScreenSaverSetting, &QGSettings::changed, this, [=](const QString key){
+        if ("idleActivationEnabled" == key) {
+            auto status = qScreenSaverSetting->get(ACTIVE_KEY).toBool();
+            enableSwitchBtn->setChecked(status);
+        }
     });
 
-    connect(ui->idleSlider, &QSlider::valueChanged, this, [=](int value){
-        //刷新分钟显示
-        ui->idleLineEdit->blockSignals(true);
-        ui->idleLineEdit->setText(QString::number(value));
-        ui->idleLineEdit->blockSignals(false);
-    });
-    connect(ui->idleSlider, &QSlider::sliderReleased, this, [=]{
-        int value = ui->idleSlider->value();
 
+//    connect(lockSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked){
+//        //REVIEW*** g_object_unref faild
+//        //    screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
+//        //    g_settings_set_boolean(screensaver_settings, LOCK_KEY, status);
+//        //    if (screensaver_settings)
+//        //            g_object_unref(screensaver_settings);
+//        const QByteArray ba(SCREENSAVER_SCHEMA);
+//        QGSettings * settings = new QGSettings(ba);
+//        settings->set(LOCK_KEY, checked);
+//        delete settings;
+//    });
+
+//    connect(uslider, &QSlider::valueChanged, this, [=](int value){
+//        //刷新分钟显示
+//        ui->idleLineEdit->blockSignals(true);
+//        ui->idleLineEdit->setText(QString::number(value));
+//        ui->idleLineEdit->blockSignals(false);
+//    });
+    connect(uslider, &QSlider::valueChanged, this, [=]{
+        int value = convertToLocktime(uslider->value());
         session_settings = g_settings_new(SESSION_SCHEMA);
         g_settings_set_int(session_settings, IDLE_DELAY_KEY, value);
         g_object_unref(session_settings);
     });
 
+    connect(qSessionSetting, &QGSettings::changed, this,[=](const QString& key){
+       if ("idleDelay" == key) {
+           auto value = qSessionSetting->get(key).toInt();
+           uslider->setValue(lockConvertToSlider(value));
+       }
+    });
+
+    connect(ui->comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(themesComboxChanged(int)));
+
+
+    connect(ui->previewWidget, &QWidget::destroyed, this, [=]{
+        closeScreensaver();
+    });
 }
 
 void Screensaver::initPreviewWidget(){
@@ -210,7 +267,7 @@ void Screensaver::initEnableBtnStatus(){
     enableSwitchBtn->blockSignals(false);
 
     //初始化LockWidget状态
-    ui->lockWidget->setVisible(active);
+    ui->lockFrame->setVisible(false);
 
     bool locked;
     locked = settings->get(LOCK_KEY).toBool();
@@ -233,7 +290,14 @@ void Screensaver::initThemeStatus(){
 
     ui->comboBox->blockSignals(true);
 
-    screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
+    QByteArray id(SCREENSAVER_SCHEMA);
+    if (QGSettings::isSchemaInstalled(id)) {
+        screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
+    } else {
+        qDebug()<<"org.ukui.screensaver not installed"<<endl;
+        return ;
+    }
+
     mode = g_settings_get_enum(screensaver_settings, MODE_KEY);
 
     if (mode == MODE_DEFAULT_UKUI){
@@ -242,21 +306,24 @@ void Screensaver::initThemeStatus(){
     else if (mode == MODE_BLANK_ONLY){
         ui->comboBox->setCurrentIndex(1); //Black_Only
     }
-    else if (mode == MODE_RANDOM){
-        ui->comboBox->setCurrentIndex(2); //Random
-    }
+//    else if (mode == MODE_RANDOM){
+//        ui->comboBox->setCurrentIndex(2); //Random
+//    }
     else{
         gchar ** strv;
         strv = g_settings_get_strv(screensaver_settings, THEMES_KEY);
-
         if (strv != NULL){
             name = g_strdup(strv[0]);
-            QString nameqt = QString(name);
-            SSThemeInfo info = (SSThemeInfo)infoMap.find(name).value();
-            ui->comboBox->setCurrentText(info.name);
+
+            QString dest =  (infoMap.find(name) != infoMap.end()) ? infoMap.value(name).name : "";
+
+            if (dest == "")
+                ui->comboBox->setCurrentIndex(1); //
+            else
+                ui->comboBox->setCurrentText(dest);
         }
         else
-            ui->comboBox->setCurrentIndex(0); //no data, default Blank_Only
+            ui->comboBox->setCurrentIndex(1); //no data, default Blank_Only
         g_strfreev(strv);
     }
     g_object_unref(screensaver_settings);
@@ -269,13 +336,17 @@ void Screensaver::initIdleSliderStatus(){
     session_settings = g_settings_new(SESSION_SCHEMA);
     minutes = g_settings_get_int(session_settings, IDLE_DELAY_KEY);
 
-    ui->idleSlider->blockSignals(true);
-    ui->idleSlider->setValue(minutes);
-    ui->idleSlider->blockSignals(false);
+    uslider->blockSignals(true);
+    uslider->setValue(lockConvertToSlider(minutes));
+    uslider->blockSignals(false);
 
-    ui->idleLineEdit->blockSignals(true);
-    ui->idleLineEdit->setText(QString::number(minutes));
-    ui->idleLineEdit->blockSignals(true);
+//    ui->idleSlider->blockSignals(true);
+//    ui->idleSlider->setValue(minutes);
+//    ui->idleSlider->blockSignals(false);
+
+//    ui->idleLineEdit->blockSignals(true);
+//    ui->idleLineEdit->setText(QString::number(minutes));
+//    ui->idleLineEdit->blockSignals(true);
 
     g_object_unref(session_settings);
 }
@@ -323,6 +394,8 @@ void Screensaver::status_init(){
     int mode;
     char * name;
 
+    screensaver_bin = QString(QT_INSTALL_LIBS) + "/ukui-screensaver/ukui-screensaver-default";
+
     screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
     mode = g_settings_get_enum(screensaver_settings, MODE_KEY);
     if (mode == MODE_DEFAULT_UKUI){
@@ -340,7 +413,6 @@ void Screensaver::status_init(){
 
         if (strv != NULL){
             name = g_strdup(strv[0]);
-            QString nameqt = QString(name);
             SSThemeInfo info = (SSThemeInfo)infoMap.find(name).value();
             ui->comboBox->setCurrentText(info.name);
         }
@@ -367,12 +439,11 @@ void Screensaver::status_init(){
 
     //获取空闲时间
     int minutes;
-    session_settings = g_settings_new(SESSION_SCHEMA);
     minutes = g_settings_get_int(session_settings, IDLE_DELAY_KEY);
+    uslider->setValue(lockConvertToSlider(minutes));
 //    ui->idleSlider->setValue(minutes);
 //    ui->idleLabel->setText(QString("%1%2").arg(minutes).arg(tr("minutes")));
 
-    g_object_unref(session_settings);
 
     //获取功能列表
 //    PublicData * publicdata = new PublicData();
@@ -381,7 +452,7 @@ void Screensaver::status_init(){
     //connect
 //    connect(ui->powerBtn, &QPushButton::clicked, this, [=]{pluginWidget->emitting_toggle_signal(tmpList.at(2), SYSTEM, 0);});
 
-    connect(ui->idleSlider, SIGNAL(sliderReleased()), this, SLOT(slider_released_slot())); //改gsettings
+//    connect(uslider, SIGNAL(sliderReleased()), this, SLOT(slider_released_slot())); //改gsettings
 //    connect(activeswitchbtn, SIGNAL(checkedChanged(bool)), this, SLOT(activebtn_changed_slot(bool)));
 //    connect(lockswitchbtn, SIGNAL(checkedChanged(bool)), this, SLOT(lockbtn_changed_slot(bool)));
     connect(ui->comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(combobox_changed_slot(int)));
@@ -391,29 +462,28 @@ void Screensaver::status_init(){
 //    delete publicdata;
 }
 
-#define UKUI_SCREENSAVER_BIN "/usr/lib/ukui-screensaver/ukui-screensaver-default"
 void Screensaver::startupScreensaver(){
     //关闭屏保
     closeScreensaver();
-    qDebug() << Q_FUNC_INFO << mPreviewWidget->winId();
+    qDebug() << Q_FUNC_INFO << ui->previewWidget->winId();
     if (ui->comboBox->currentIndex() == 0){//UKUI
         QStringList args;
-        args << "-window-id" << QString::number(mPreviewWidget->winId());
+        args << "-window-id" << QString::number(ui->previewWidget->winId());
         //启动屏保
-        process->startDetached(UKUI_SCREENSAVER_BIN, args);
-        runStringList.append(UKUI_SCREENSAVER_BIN);
+        process->startDetached(screensaver_bin, args);
+        runStringList.append(screensaver_bin);
     }
     else if (ui->comboBox->currentIndex() == 1){//黑屏
-        mPreviewWidget->update();
-    }
-    else if (ui->comboBox->currentIndex() == 2){//随机
-        mPreviewWidget->update();
+        ui->previewWidget->update();
     }
+//    else if (ui->comboBox->currentIndex() == 2){//随机
+//        ui->previewWidget->update();
+//    }
     else{//屏保
 
         SSThemeInfo info = ui->comboBox->currentData().value<SSThemeInfo>();
         QStringList args;
-        args << "-window-id" << QString::number(mPreviewWidget->winId());
+        args << "-window-id" << QString::number(ui->previewWidget->winId());
         //启动屏保
         process->startDetached(info.exec, args);
         runStringList.append(info.exec);
@@ -438,8 +508,8 @@ void Screensaver::kill_and_start(){
         QStringList args;
         args << "-window-id" << QString::number(mPreviewWidget->winId());
         //启动屏保
-        process->startDetached(UKUI_SCREENSAVER_BIN, args);
-        runStringList.append(UKUI_SCREENSAVER_BIN);
+        process->startDetached(screensaver_bin, args);
+        runStringList.append(screensaver_bin);
     }
     else if (ui->comboBox->currentIndex() == 1){//黑屏
         mPreviewWidget->update();
@@ -458,14 +528,80 @@ void Screensaver::kill_and_start(){
 }
 
 
-void Screensaver::set_idle_gsettings_value(int value){
-    session_settings = g_settings_new(SESSION_SCHEMA);
+int Screensaver::convertToLocktime(const int value) {
+    switch (value) {
+    case 1:
+        return 1;
+        break;
+    case 2:
+        return 5;
+        break;
+    case 3:
+        return 10;
+        break;
+    case 4:
+        return 30;
+        break;
+    case 5:
+        return 45;
+        break;
+    case 6:
+        return 60;
+        break;
+    case 7:
+        return 90;
+        break;
+    case 8:
+        return 180;
+        break;
+    default:
+        return 1;
+        break;
+    }
+}
+
+int Screensaver::lockConvertToSlider(const int value) {
+    switch (value) {
+    case 1:
+        return 1;
+        break;
+    case 5:
+        return 2;
+        break;
+    case 10:
+        return 3;
+        break;
+    case 30:
+        return 4;
+        break;
+    case 45:
+        return 5;
+        break;
+    case 60:
+        return 6;
+        break;
+    case 90:
+        return 7;
+        break;
+    case 180:
+        return 8;
+        break;
+    default:
+        return 1;
+        break;
+    }
+}
+
+
+
+void Screensaver::set_idle_gsettings_value(int value){    
     g_settings_set_int(session_settings, IDLE_DELAY_KEY, value);
 }
 
 void Screensaver::slider_released_slot(){
     int minutes;
-    minutes = ui->idleSlider->value();
+//    minutes = ui->idleSlider->value();
+    minutes = convertToLocktime(uslider->value());
     set_idle_gsettings_value(minutes);
 }
 
@@ -497,6 +633,34 @@ void Screensaver::activebtn_changed_slot(bool status){
 
 }
 
+void Screensaver::themesComboxChanged(int index){
+
+    char ** strv = NULL;
+
+    //设置屏保
+    screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
+    if (index == 0){
+        g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_DEFAULT_UKUI);
+    } else if (index == 1){
+        g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_BLANK_ONLY);
+    } else {
+        g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_SINGLE);
+        //获取当前屏保的id
+        QVariant variant = ui->comboBox->itemData(index);
+        SSThemeInfo info = variant.value<SSThemeInfo>();
+        QByteArray ba = info.id.toLatin1();
+        strv = g_strsplit(ba.data(), "%%%", 1);
+        qDebug() << Q_FUNC_INFO << "wxy-----------" <<strv;
+        g_settings_set_strv(screensaver_settings, THEMES_KEY, (const gchar * const*)strv);
+    }
+    g_object_unref(screensaver_settings);
+    g_strfreev(strv);
+
+    //刷新预览
+    startupScreensaver();
+
+}
+
 void Screensaver::combobox_changed_slot(int index){
     char ** strv = NULL;
 
@@ -506,9 +670,10 @@ void Screensaver::combobox_changed_slot(int index){
         g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_DEFAULT_UKUI);
     }
     else if (index == 1){ //Blank_Only
+        qDebug()<<"this is Blan_only----------------->"<<endl;
         g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_BLANK_ONLY);
     }
-    else if (index == 2){ //Random
+    else if (index == 10000){ //Random not in
 //        int mode = MODE_RANDOM;
         g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_RANDOM);
         //REVIEW*** 二维字符数组赋值字符串段错误？
