@@ -20,7 +20,7 @@
 #include "theme.h"
 #include "ui_theme.h"
 
-#include <QGSettings/QGSettings>
+#include <QGSettings>
 
 #include "SwitchButton/switchbutton.h"
 
@@ -28,8 +28,11 @@
 #include "widgetgroup.h"
 #include "cursor/xcursortheme.h"
 
-#include <QDebug>
+#include "../../../shell/customstyle.h"
 
+#include <QDebug>
+#include <QtDBus/QDBusConnection>
+#include <QtConcurrent>
 /**
  * GTK主题
  */
@@ -43,10 +46,12 @@
  */
 #define THEME_QT_SCHEMA "org.ukui.style"
 #define MODE_QT_KEY "style-name"
+#define THEME_TRAN_KEY "menu-transparency"
+#define PEONY_TRAN_KEY "peony-side-bar-transparency"
+
 /* QT图标主题 */
 #define ICON_QT_KEY "icon-theme-name"
 
-
 /**
  * 窗口管理器Marco主题
  */
@@ -62,6 +67,15 @@
 
 #define ICONWIDGETHEIGH 74
 
+/**
+ * 透明度设置
+ */
+#define PERSONALSIE_SCHEMA "org.ukui.control-center.personalise"
+#define PERSONALSIE_TRAN_KEY "transparency"
+#define PERSONALSIE_BLURRY_KEY "blurry"
+
+const QString defCursor = "DMZ-White";
+const int transparency = 95;
 
 namespace {
 
@@ -84,7 +98,7 @@ namespace {
         "split_v",
     };
 
-    const int numCursors      = 9;     // The number of cursors from the above list to be previewed
+    const int numCursors = 9;     // The number of cursors from the above list to be previewed
 }
 
 Theme::Theme()
@@ -94,21 +108,28 @@ Theme::Theme()
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("theme");
+    pluginName = tr("Theme");
     pluginType = PERSONALIZED;
 
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
     settingsCreate = false;
 
     const QByteArray id(THEME_GTK_SCHEMA);
     const QByteArray idd(THEME_QT_SCHEMA);
     const QByteArray iid(CURSOR_THEME_SCHEMA);
-
-    //设置样式
-    setupStylesheet();
+    const QByteArray iiid(PERSONALSIE_SCHEMA);
+    if (QGSettings::isSchemaInstalled(iiid)) {
+        personliseGsettings = new QGSettings(iiid);
+    }
     //设置组件
     setupComponent();
 
-    if (QGSettings::isSchemaInstalled(id) && QGSettings::isSchemaInstalled(idd) && QGSettings::isSchemaInstalled(iid)){
+    // init kwin settings
+    setupSettings();
+
+    if (QGSettings::isSchemaInstalled(id) && QGSettings::isSchemaInstalled(idd)
+            && QGSettings::isSchemaInstalled(iid)){
         gtkSettings = new QGSettings(id);
         qtSettings = new QGSettings(idd);
         curSettings = new QGSettings(iid);
@@ -118,7 +139,7 @@ Theme::Theme()
         initThemeMode();
         initIconTheme();
         initCursorTheme();
-        initEffectSettings();
+//        initEffectSettings();
         initConnection();
     } else {
         qCritical() << THEME_GTK_SCHEMA << "or" << THEME_QT_SCHEMA << "or" << CURSOR_THEME_SCHEMA << "not installed\n";
@@ -134,7 +155,15 @@ Theme::~Theme()
         delete qtSettings;
         delete curSettings;
     }
-
+    if (kwinSettings ){
+        delete kwinSettings;
+    }
+    if (kwinGsettings) {
+        delete kwinGsettings;
+    }
+    if (personliseGsettings) {
+        delete personliseGsettings;
+    }
 }
 
 QString Theme::get_plugin_name(){
@@ -153,56 +182,79 @@ void Theme::plugin_delay_control(){
 
 }
 
-void Theme::setupStylesheet(){
-    pluginWidget->setStyleSheet("background: #ffffff;");
+void Theme::setupSettings() {
+    QString filename = QDir::homePath() + "/.config/ukui-kwinrc";
+    kwinSettings = new QSettings(filename, QSettings::IniFormat);
 
-    ui->controlWidget->setStyleSheet("QWidget#controlWidget{background: #F4F4F4; border-radius: 6px;}");
+    kwinSettings->beginGroup("Plugins");
 
-    ui->effectWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-    ui->line->setStyleSheet("QFrame{border-top: 1px solid #CCCCCC; border-left: none; border-right: none; border-bottom: none;}");
+    bool kwin = kwinSettings->value("blurEnabled", kwin).toBool();
 
-    ui->resetBtn->setStyleSheet("QPushButton#resetBtn{background: #F4F4F4; border: none; border-radius: 4px;}"
-                                "QPushButton:hover:!pressed#resetBtn{border: none; background: #3D6BE5; border-radius: 2px;}"
-                                "QPushButton:hover:pressed#resetBtn{border: none; background: #2C5AD6; border-radius: 2px;}");
+    kwinSettings->endGroup();
 
-    ui->transparencySlider->setStyleSheet("QSlider{height: 20px;}"
-                                          "QSlider::groove:horizontal{border: none;}"
-                                          "QSlider::add-page:horizontal{background: #808080; border-radius: 2px; margin-top: 8px; margin-bottom: 9px;}"
-                                          "QSlider::sub-page:horizontal{background: #3D6BE5; border-radius: 2px; margin-top: 8px; margin-bottom: 9px;}"
-                                          "QSlider::handle:horizontal{width: 20px; height: 20px; border-image: url(:/img/plugins/fonts/bigRoller.png);}"
-                                          "");
+    effectSwitchBtn->setChecked(kwin);
+
+    QFileInfo dir(filename);
+    if (!dir.isFile()) {
+        effectSwitchBtn->setChecked(true);
+    }
+
+    if (effectSwitchBtn->isChecked()) {
+        ui->transFrame->setVisible(true);
+    } else {
+        ui->transFrame->setVisible(false);
+    }
 }
 
 void Theme::setupComponent(){
 
     ui->lightButton->hide();
-
-    //无用的控制主题
-    ui->label_3->hide();
+    //隐藏现阶段不支持功能
+    ui->controlLabel->hide();
     ui->controlWidget->hide();
 
-    ui->defaultButton->setProperty("value", "ukui-white");
-    ui->lightButton->setProperty("value", "ukui-default");
-    ui->darkButton->setProperty("value", "ukui-black");
+    ui->defaultButton->setProperty("value", "ukui-default");
+//    ui->lightButton->setProperty("value", "ukui-default");
+    ui->darkButton->setProperty("value", "ukui-dark");
 
     buildThemeModeBtn(ui->defaultButton, tr("Default"), "default");
     buildThemeModeBtn(ui->lightButton, tr("Light"), "light");
     buildThemeModeBtn(ui->darkButton, tr("Dark"), "dark");
 
+    ui->tranSlider->setRange(35, 100);
+    ui->tranSlider->setTickInterval(1);
+    ui->tranSlider->setPageStep(1);
+
+    ui->tranSlider->setValue(static_cast<int>(personliseGsettings->get(PERSONALSIE_TRAN_KEY).toDouble() * 100));
+    ui->tranLabel->setText(QString::number(static_cast<double>(ui->tranSlider->value())/100.0));
+    connect(ui->tranSlider, &QSlider::valueChanged, [=](int value){
+        personliseGsettings->set(PERSONALSIE_TRAN_KEY, static_cast<double>(value)/100.0);
+        qtSettings->set(THEME_TRAN_KEY, value);
+        qtSettings->set(PEONY_TRAN_KEY, value);
+        ui->tranLabel->setText(QString::number(static_cast<double>(ui->tranSlider->value())/100.0));
+    });
     setupControlTheme();
 
-    ui->effectLabel->hide();
-    ui->effectWidget->hide();
+//    ui->effectLabel->hide();
+//    ui->effectWidget->hide();
 
     //构建并填充特效开关按钮
     effectSwitchBtn = new SwitchButton(pluginWidget);
     ui->effectHorLayout->addWidget(effectSwitchBtn);
 
+    ui->kwinFrame->setVisible(false);
+    ui->transFrame->setVisible(true);
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+    ui->transFrame->setVisible(false);
+    ui->effectFrame->setVisible(false);
+#else
+#endif
 }
 
 void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
     //设置默认按钮
-    button->setStyleSheet("QPushButton{background: #ffffff; border: none;}");
+//    button->setStyleSheet("QPushButton{background: #ffffff; border: none;}");
 
     QVBoxLayout * baseVerLayout = new QVBoxLayout(button);
     baseVerLayout->setSpacing(8);
@@ -219,12 +271,7 @@ void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
     QLabel * statusLabel = new QLabel(button);
     statusLabel->setFixedSize(QSize(16, 16));
     statusLabel->setScaledContents(true);
-    connect(ui->themeModeBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), [=](QAbstractButton * eBtn){
-        if (eBtn == button)
-            statusLabel->setPixmap(QPixmap("://img/plugins/theme/selected.png"));
-        else
-            statusLabel->clear();
-    });
+
     QLabel * nameLabel = new QLabel(button);
     QSizePolicy nameSizePolicy = nameLabel->sizePolicy();
     nameSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
@@ -232,6 +279,21 @@ void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
     nameLabel->setSizePolicy(nameSizePolicy);
     nameLabel->setText(name);
 
+#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
+    connect(ui->themeModeBtnGroup, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), [=](QAbstractButton * eBtn){
+#else
+    connect(ui->themeModeBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), [=](QAbstractButton * eBtn){
+#endif
+        if (eBtn == button) {
+            nameLabel->setStyleSheet("color: #ffffff;");
+            statusLabel->setPixmap(QPixmap("://img/plugins/theme/selected.svg"));
+        }
+        else {
+            nameLabel->setStyleSheet("color: palette(windowText);");
+            statusLabel->clear();
+        }
+    });
+
     bottomHorLayout->addStretch();
     bottomHorLayout->addWidget(statusLabel);
     bottomHorLayout->addWidget(nameLabel);
@@ -244,8 +306,24 @@ void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
 }
 
 void Theme::initThemeMode(){
+    //监听主题改变
+    connect(qtSettings, &QGSettings::changed, this, [=](const QString &key){
+        if (key == "styleName") {
+            //获取当前主题
+            QString currentThemeMode = qtSettings->get(key).toString();
+            writeKwinSettings(true, currentThemeMode);
+            for (QAbstractButton * button : ui->themeModeBtnGroup->buttons()){
+                QVariant valueVariant = button->property("value");
+                if (valueVariant.isValid() && valueVariant.toString() == currentThemeMode) {
+                    button->click();
+                }
+            }
+        }
+    });
+
     //获取当前主题
     QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
+    qApp->setStyle(new InternalStyle(currentThemeMode));
     //设置界面
     for (QAbstractButton * button : ui->themeModeBtnGroup->buttons()){
         QVariant valueVariant = button->property("value");
@@ -254,13 +332,30 @@ void Theme::initThemeMode(){
 //            button->setChecked(true);
     }
 
+#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
+    connect(ui->themeModeBtnGroup, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), [=](QAbstractButton * button){
+#else
     connect(ui->themeModeBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, [=](QAbstractButton * button){
-        //设置主题
+#endif
+//        //设置主题
         QString themeMode = button->property("value").toString();
         QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
+
+
+        qApp->setStyle(new InternalStyle(themeMode));
         if (QString::compare(currentThemeMode, themeMode)){
-            qtSettings->set(MODE_QT_KEY, themeMode);
-            gtkSettings->set(MODE_GTK_KEY, themeMode);
+            QString tmpMode;
+            if ("ukui-dark" == themeMode) {
+                tmpMode = "ukui-black";
+            } else {
+                tmpMode = "ukui-white";
+            }
+            gtkSettings->set(MODE_GTK_KEY, tmpMode);
+
+            QtConcurrent::run([=](){
+                qtSettings->set(MODE_QT_KEY, themeMode);
+            });
+            writeKwinSettings(true, themeMode);
         }
     });
 }
@@ -299,6 +394,7 @@ void Theme::initIconTheme(){
             }
 
             ThemeWidget * widget = new ThemeWidget(QSize(48, 48), dullTranslation(themedir.section("-", -1, -1, QString::SectionSkipEmpty)), showIconsList);
+//            widget->setFrameShape(QFrame::Shape::Box);
             widget->setValue(themedir);
             //加入Layout
             ui->iconThemeVerLayout->addWidget(widget);
@@ -335,7 +431,7 @@ void Theme::setupControlTheme(){
         button->setFixedSize(QSize(48, 48));
         button->setCheckable(true);
         QString btnStyle = QString("QPushButton{background: %1; border-radius: 4px;}").arg(color);
-        button->setStyleSheet(btnStyle);
+//        button->setStyleSheet(btnStyle);
         colorBtnGroup->addButton(button, colorStringList.indexOf(color));
 
 
@@ -357,10 +453,10 @@ void Theme::setupControlTheme(){
         selectedColorLabel->setPixmap(QPixmap("://img/plugins/theme/selected.png"));
         //初始化选中图标状态
         selectedColorLabel->setVisible(button->isChecked());
-        connect(colorBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this,[=]{
-            selectedColorLabel->setVisible(button->isChecked());
-            //设置控件主题
-        });
+//        connect(colorBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this,[=]{
+//            selectedColorLabel->setVisible(button->isChecked());
+//            //设置控件主题
+//        });
 
         colorHorLayout->addStretch();
         colorHorLayout->addWidget(selectedColorLabel);
@@ -400,11 +496,13 @@ void Theme::initCursorTheme(){
         XCursorTheme *cursorTheme = new XCursorTheme(path);
 
         for(int i = 0; i < numCursors; i++){
-            QImage image = cursorTheme->loadImage(cursor_names[i],20);
+            int size = qApp->devicePixelRatio() * 8;
+            QImage image = cursorTheme->loadImage(cursor_names[i],size);
             cursorVec.append(QPixmap::fromImage(image));
         }
 
         ThemeWidget * widget  = new ThemeWidget(QSize(24, 24), cursor, cursorVec);
+//        widget->setFrameShape(QFrame::Shape::Box);
         widget->setValue(cursor);
 
         //加入Layout
@@ -414,7 +512,7 @@ void Theme::initCursorTheme(){
         cursorThemeWidgetGroup->addWidget(widget);
 
         //初始化指针主题选中界面
-        if (currentCursorTheme == cursor){
+        if (currentCursorTheme == cursor || (currentCursorTheme.isEmpty() && cursor == defCursor)){
             cursorThemeWidgetGroup->setCurrentWidget(widget);
             widget->setSelectedStatus(true);
         } else {
@@ -430,7 +528,14 @@ void Theme::initEffectSettings(){
 }
 
 void Theme::initConnection() {
+
     connect(ui->resetBtn, &QPushButton::clicked, this, &Theme::resetBtnClickSlot);
+
+    connect(effectSwitchBtn, &SwitchButton::checkedChanged, [this](bool checked) {
+        QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
+        ui->transFrame->setVisible(checked);
+        writeKwinSettings(checked, currentThemeMode);
+    });
 }
 
 QStringList Theme::_getSystemCursorThemes(){
@@ -461,23 +566,31 @@ QString Theme::dullTranslation(QString str){
         return QObject::tr("Unknown");
 }
 
+// reset all of themes, include cursor, icon,and etc...
 void Theme::resetBtnClickSlot() {
 
     // reset theme(because MODE_QT_KEY's default is null, use "SET" to reset default key )
-    QString theme = "ukui-white";
-    qtSettings->set(MODE_QT_KEY, theme);
-    gtkSettings->set(MODE_GTK_KEY, theme);
+//    QString theme = "ukui-default";
+//    qtSettings->set(MODE_QT_KEY, theme);
+//    gtkSettings->set(MODE_GTK_KEY, theme);
+//    emit ui->defaultButton->clicked();
+    emit ui->themeModeBtnGroup->buttonClicked(ui->defaultButton);
+
+    ui->tranSlider->setValue(transparency);
+
+//    ui->defaultButton->setChecked(true);
 
     // reset cursor default theme
-    QString cursorTheme = "breeze_cursors";
+    QString cursorTheme = "DMZ-White";
     curSettings->set(CURSOR_THEME_KEY,cursorTheme);
 
-
     //reset icon default theme
     qtSettings->reset(ICON_QT_KEY);
+    qtSettings->reset(THEME_TRAN_KEY);
+    qtSettings->reset(PEONY_TRAN_KEY);
     gtkSettings->reset(ICON_GTK_KEY);
 
-
+    ui->tranSlider->setValue(transparency);
 
     clearLayout(ui->iconThemeVerLayout->layout(), true);
     clearLayout(ui->cursorVerLayout->layout(), true);
@@ -487,6 +600,59 @@ void Theme::resetBtnClickSlot() {
     initCursorTheme();
 }
 
+void Theme::writeKwinSettings(bool change, QString theme, int effect) {
+
+    QString th = "";
+    if ("ukui-default" == theme) {
+        th = "__aurorae__svg__Ukui-classic";
+    } else if ("ukui-dark" == theme){
+        th = "__aurorae__svg__Ukui-classic-dark";
+    }
+    if (!change) {
+        kwinSettings->clear();
+        kwinSettings->beginGroup("Plugins");
+        kwinSettings->setValue("blurEnabled",false);
+        kwinSettings->setValue("contrastEnabled",false);
+        kwinSettings->setValue("kwin4_effect_dialogparentEnabled",false);
+        kwinSettings->setValue("kwin4_effect_fadingpopupsEnabled",false);
+        kwinSettings->setValue("kwin4_effect_frozenappEnabled",false);
+        kwinSettings->setValue("kwin4_effect_loginEnabled",false);
+        kwinSettings->setValue("kwin4_effect_logoutEnabled",false);
+        kwinSettings->setValue("kwin4_effect_maximizeEnabled",false);
+        kwinSettings->setValue("kwin4_effect_maximizeEnabled",false);
+        kwinSettings->setValue("kwin4_effect_morphingpopupsEnabled",false);
+        kwinSettings->setValue("kwin4_effect_squashEnabled",false);
+        kwinSettings->setValue("kwin4_effect_translucencyEnabled",false);
+        kwinSettings->setValue("presentwindowsEnabled",false);
+        kwinSettings->setValue("screenedgeEnabled",false);
+        kwinSettings->setValue("slideEnabled",false);
+        kwinSettings->setValue("slidingpopupsEnabled",false);
+        kwinSettings->setValue("zoomEnabled",false);
+        kwinSettings->endGroup();
+    } else {
+        kwinSettings->clear();
+        kwinSettings->beginGroup("Plugins");
+        kwinSettings->setValue("blurEnabled",true);
+        kwinSettings->endGroup();
+    }
+
+    if (!th.isEmpty()) {
+        kwinSettings->beginGroup("org.kde.kdecoration2");
+        kwinSettings->setValue("theme", th);
+        kwinSettings->setValue("library", "org.ukui.kwin.aurorae");
+        kwinSettings->endGroup();
+    }
+
+    kwinSettings->sync();
+
+#if QT_VERSION <= QT_VERSION_CHECK(5,12,0)
+
+#else
+        QDBusMessage message = QDBusMessage::createSignal("/KWin", "org.ukui.KWin", "reloadConfig");
+        QDBusConnection::sessionBus().send(message);
+#endif
+}
+
 void Theme::clearLayout(QLayout* mlayout, bool deleteWidgets)
 {
     if ( mlayout->layout() != NULL )
@@ -499,3 +665,44 @@ void Theme::clearLayout(QLayout* mlayout, bool deleteWidgets)
         }
     }
 }
+
+double Theme::convertToTran(const int value)
+{
+    switch (value) {
+    case 1:
+        return 0.2;
+        break;
+    case 2:
+        return 0.4;
+        break;
+    case 3:
+        return 0.6;
+        break;
+    case 4:
+        return 0.8;
+        break;
+    case 5:
+        return 1.0;
+        break;
+    default:
+        return 1.0;
+        break;
+    }
+}
+
+int Theme::tranConvertToSlider(const double value)
+{
+    if (0.2 ==  value) {
+        return 1;
+    } else if (0.4 ==  value){
+        return 2;
+    } else if (0.6 ==  value){
+        return 3;
+    } else if (0.8 ==  value){
+        return 4;
+    } else if (1.0 ==  value){
+        return 5;
+    } else {
+        return 5;
+    }
+}
