@@ -27,6 +27,9 @@
 #include "MaskWidget/maskwidget.h"
 
 #include <QDebug>
+#include <QDesktopServices>
+
+const QString kylinUrl = "https://www.ubuntukylin.com/wallpaper.html";
 
 enum{
     PICTURE, //图片背景
@@ -43,18 +46,16 @@ enum{
 Wallpaper::Wallpaper()
 {
     ui = new Ui::Wallpaper;
-    itemDelege = new QStyledItemDelegate();
     pluginWidget = new QWidget;
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("background");
+    pluginName = tr("Background");
     pluginType = PERSONALIZED;
 
-    settingsCreate = false;
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
-    //设置样式
-    setupQStylesheet();
+    settingsCreate = false;
     //初始化控件
     setupComponent();
     //初始化gsettings
@@ -68,7 +69,6 @@ Wallpaper::Wallpaper()
     }
     //构建xmlhandle对象
     xmlhandleObj = new XmlHandle();
-
 }
 
 Wallpaper::~Wallpaper()
@@ -77,9 +77,7 @@ Wallpaper::~Wallpaper()
     if (settingsCreate){
         delete bgsettings;
     }
-
     delete xmlhandleObj;
-
 }
 
 QString Wallpaper::get_plugin_name(){
@@ -97,42 +95,18 @@ QWidget *Wallpaper::get_plugin_ui(){
 void Wallpaper::plugin_delay_control(){
 }
 
-void Wallpaper::setupQStylesheet(){
-    pluginWidget->setStyleSheet("background: #ffffff;");
-
-    ui->previewLabel->setStyleSheet("QLabel#previewLabel{border-radius: 6px;}");
-
-    ui->switchWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-
-//    ui->listWidget->setStyleSheet("QListWidget#listWidget{background: #ffffff; border: none;}");
-//    ui->colorListWidget->setStyleSheet("QListWidget#colorListWidget{background: #ffffff; border: none;}");
-
-    QString btnQss = QString("QPushButton{background: #E9E9E9; border-radius: 4px;}"
-                             "QPushButton:hover:!pressed{background: #3d6be5; border: none; border-radius: 4px;}"
-                             "QPushButton:hover:pressed{background: #415FC4; border: none; border-radius: 4px;}");
-    ui->browserLocalwpBtn->setStyleSheet(btnQss);
-    ui->browserOnlinewpBtn->setStyleSheet(btnQss);
-
-    ui->resetBtn->setStyleSheet(btnQss);
-}
-
 void Wallpaper::setupComponent(){
 
 //    ui->browserLocalwpBtn->hide();
-    ui->browserOnlinewpBtn->hide();
+//    ui->browserOnlinewpBtn->hide();
     //背景形式
     QStringList formList;
     formList << tr("picture") << tr("color")/* << tr("slideshow")*/ ;
-    ui->formComBox->setItemDelegate(itemDelege);
-    ui->formComBox->setMaxVisibleItems(5);
 //    ui->formComBox->addItems(formList);
     ui->formComBox->addItem(formList.at(0), PICTURE);
     ui->formComBox->addItem(formList.at(1), COLOR);
 //    ui->formComBox->addItem(formList.at(2), SLIDESHOW);
 
-    ui->picOptionsComBox->setItemDelegate(itemDelege);
-    ui->picOptionsComBox->setMaxVisibleItems(5);
-
     //预览遮罩
     MaskWidget * maskWidget = new MaskWidget(ui->previewLabel);
     maskWidget->setGeometry(0, 0, ui->previewLabel->width(), ui->previewLabel->height());
@@ -146,6 +120,46 @@ void Wallpaper::setupComponent(){
     colorFlowLayout->setContentsMargins(0, 0, 0, 0);
     ui->colorListWidget->setLayout(colorFlowLayout);
 
+
+    colWgt = new HoverWidget("");
+    colWgt->setObjectName("colWgt");
+    colWgt->setMinimumSize(QSize(580, 50));
+    colWgt->setMaximumSize(QSize(960, 50));
+    colWgt->setStyleSheet("HoverWidget#colWgt{background: palette(button); border-radius: 4px;}HoverWidget:hover:!pressed#colWgt{background: #3D6BE5; border-radius: 4px;}");
+    QHBoxLayout *addLyt = new QHBoxLayout;
+    QLabel * iconLabel = new QLabel();
+    QLabel * textLabel = new QLabel(tr("Custom color"));
+    QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+    iconLabel->setPixmap(pixgray);
+    addLyt->addWidget(iconLabel);
+    addLyt->addWidget(textLabel);
+    addLyt->addStretch();
+    colWgt->setLayout(addLyt);
+
+    // 悬浮改变Widget状态
+    connect(colWgt, &HoverWidget::enterWidget, this, [=](QString mname){
+        Q_UNUSED(mname);
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "white", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(base);");
+
+    });
+    // 还原状态
+    connect(colWgt, &HoverWidget::leaveWidget, this, [=](QString mname){
+        Q_UNUSED(mname);
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(windowText);");
+    });
+
+    connect(colWgt, &HoverWidget::widgetClicked,[=](QString mname){
+        Q_UNUSED(mname);
+        colordialog = new ColorDialog();
+        connect(colordialog,&ColorDialog::colorSelected,this,&Wallpaper::colorSelectedSlot);
+        colordialog->exec();
+
+    });
+
     //壁纸放置方式
     ui->picOptionsComBox->addItem(tr("wallpaper"), "wallpaper");
     ui->picOptionsComBox->addItem(tr("centered"), "centered");
@@ -211,6 +225,11 @@ void Wallpaper::setupConnect(){
     connect(ui->browserLocalwpBtn, &QPushButton::clicked, [=]{
         showLocalWpDialog();
     });
+
+
+    connect(ui->browserOnlinewpBtn, &QPushButton::clicked, [=]{
+        QDesktopServices::openUrl(QUrl(kylinUrl));
+    });
     connect(ui->resetBtn, SIGNAL(clicked(bool)), this, SLOT(resetDefaultWallpaperSlot()));
 
     ///纯色背景
@@ -237,9 +256,15 @@ void Wallpaper::setupConnect(){
             ui->previewStackedWidget->setCurrentIndex(COLOR);
         });
         colorFlowLayout->addWidget(button);
-    }
 
+    }
+    colorFlowLayout->addWidget(colWgt);
+
+#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
+    connect(ui->formComBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), [=](int index){
+#else
     connect(ui->formComBox, QOverload<int>::of(&QComboBox::currentIndexChanged), [=](int index){
+#endif
         Q_UNUSED(index)
         //切换
         int currentPage = ui->formComBox->currentData(Qt::UserRole).toInt();
@@ -317,6 +342,7 @@ int Wallpaper::_getCurrentBgForm(){
 void Wallpaper::initBgFormStatus(){
     initPreviewStatus();
 
+
     int currentIndex = _getCurrentBgForm();
     //设置当前背景形式
     ui->formComBox->blockSignals(true);
@@ -344,14 +370,12 @@ void Wallpaper::showComponent(int index){
 void Wallpaper::initPreviewStatus(){
     //设置图片背景的预览效果
     QString filename = bgsettings->get(FILENAME).toString();
+//    qDebug()<<"preview pic is---------->"<<filename<<endl;
 
     QByteArray ba = filename.toLatin1();
-    if (g_file_test(ba.data(), G_FILE_TEST_EXISTS)){
+//    if (g_file_test(ba.data(), G_FILE_TEST_EXISTS)){
         ui->previewLabel->setPixmap(QPixmap(filename).scaled(ui->previewLabel->size()));
-    } else {
-        ui->previewLabel->setPixmap(QPixmap("://img/plugins/wallpaper/none.png").scaled(ui->previewLabel->size()));
-    }
-
+//    }
 
     //设置纯色背景的预览效果
     QString color = bgsettings->get(PRIMARY).toString();
@@ -361,6 +385,19 @@ void Wallpaper::initPreviewStatus(){
     }
 }
 
+void Wallpaper::colorSelectedSlot(QColor color){
+    qDebug() << "colorSelectedSlot" << color << color.name();
+
+    QString widgetQss = QString("QWidget{background: %1; border-radius: 6px;}").arg(color.name());
+    ui->previewWidget->setStyleSheet(widgetQss);
+
+    ///设置系统纯色背景
+    bgsettings->set(FILENAME, "");
+    bgsettings->set(PRIMARY, QVariant(color.name()));
+
+    ui->previewStackedWidget->setCurrentIndex(COLOR);
+}
+
 void Wallpaper::wpOptionsChangedSlot(QString op){
     //获取当前选中的壁纸
 //    QListWidgetItem * currentitem = ui->listWidget->currentItem();
@@ -427,7 +464,7 @@ void Wallpaper::showLocalWpDialog(){
     fd.setViewMode(QFileDialog::List);
     fd.setNameFilter(filters);
     fd.setFileMode(QFileDialog::ExistingFile);
-    fd.setWindowTitle(tr("selsect custom wallpaper file"));
+    fd.setWindowTitle(tr("select custom wallpaper file"));
     fd.setLabelText(QFileDialog::Accept, tr("Select"));
     fd.setLabelText(QFileDialog::LookIn, tr("Position: "));
     fd.setLabelText(QFileDialog::FileName, tr("FileName: "));
@@ -439,12 +476,13 @@ void Wallpaper::showLocalWpDialog(){
     QString selectedfile;
     selectedfile = fd.selectedFiles().first();
 
-    ///TODO: chinese and space support
 
-    if (g_file_test(selectedfile.toLatin1().data(), G_FILE_TEST_EXISTS))
+    ///TODO: chinese and space support
+//    if (g_file_test(selectedfile.toLatin1().data(), G_FILE_TEST_EXISTS)) {
         bgsettings->set(FILENAME, QVariant(selectedfile));
-    else
-        bgsettings->reset(FILENAME);
+//    } else {
+//        bgsettings->reset(FILENAME);
+//    }
 }
 
 void Wallpaper::add_custom_wallpaper(){
@@ -455,7 +493,7 @@ void Wallpaper::add_custom_wallpaper(){
     fd.setViewMode(QFileDialog::List);
     fd.setNameFilter(filters);
     fd.setFileMode(QFileDialog::ExistingFile);
-    fd.setWindowTitle(tr("selsect custom wallpaper file"));
+    fd.setWindowTitle(tr("select custom wallpaper file"));
     fd.setLabelText(QFileDialog::Accept, tr("Select"));
     fd.setLabelText(QFileDialog::LookIn, tr("Position: "));
     fd.setLabelText(QFileDialog::FileName, tr("FileName: "));
