@@ -19,14 +19,17 @@
  */
 #include "autoboot.h"
 #include "ui_autoboot.h"
+#include "SwitchButton/switchbutton.h"
+#include "HoverWidget/hoverwidget.h"
+#include "ImageUtil/imageutil.h"
+#include "autobootworker.h"
 
 #include <QThread>
 #include <QSignalMapper>
-#include "SwitchButton/switchbutton.h"
-#include "HoverWidget/hoverwidget.h"
-#include "autobootworker.h"
-
 #include <QDebug>
+#include <QFont>
+#include <QMouseEvent>
+#include <QPushButton>
 
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
  * 后面如果用到signals时，使用Q_SIGNALS代替即可
@@ -47,9 +50,9 @@ extern "C" {
 #define HEADHEIGHT 38
 
 
-struct SaveData : QObjectUserData {
-    QString bname;
-};
+//struct SaveData : QObjectUserData {
+//    QString bname;
+//};
 
 AutoBoot::AutoBoot(){
     ui = new Ui::AutoBoot;
@@ -57,39 +60,46 @@ AutoBoot::AutoBoot(){
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    pluginName = tr("autoboot");
+    pluginName = tr("Autoboot");
     pluginType = SYSTEM;
 
-
-    pluginWidget->setStyleSheet("background: #ffffff;");
-    ui->addWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-
-    ui->listWidget->setStyleSheet("QListWidget#listWidget{background: #ffffff; border: none;}"
-                                  "");
-
-    ui->addBtn->setIcon(QIcon("://img/plugins/autoboot/add.png"));
-    ui->addBtn->setIconSize(QSize(48, 48));
-
-    ui->listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+//    ui->addFrame->installEventFilter(this);
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
 
-    ui->listWidget->setSpacing(0);
+
+//    pluginWidget->setStyleSheet("background: #ffffff;");
+//    ui->addWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
+
+//    ui->listWidget->setStyleSheet("QListWidget#listWidget{background: #ffffff; border: none;}"
+//                                  "");
+
+//    ui->addBtn->setIcon(QIcon("://img/plugins/autoboot/add.png"));
+//    ui->addBtn->setIconSize(QSize(48, 48));
+//    ui->addBtn->setStyleSheet("QPushButton{background-color:transparent;}");
+
+
+
+//    ui->listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+//    ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
+
+//    ui->listWidget->setSpacing(0);
 
     localconfigdir = g_build_filename(g_get_user_config_dir(), "autostart", NULL);
     //初始化添加界面
     dialog = new AddAutoBoot();
 
+    initAddBtn();
     initUI();
 
-    connect(ui->addBtn, &QPushButton::clicked, this, [=]{dialog->exec();});
     connect(dialog, SIGNAL(autoboot_adding_signals(QString, QString,QString,QString)), this, SLOT(add_autoboot_realize_slot(QString ,QString,QString,QString)));
 }
 
 AutoBoot::~AutoBoot()
 {
     delete ui;
-    delete dialog;
+//    delete dialog;
     g_free(localconfigdir);
 }
 
@@ -109,6 +119,46 @@ void AutoBoot::plugin_delay_control(){
 
 }
 
+void AutoBoot::initAddBtn() {
+    addWgt = new HoverWidget("");
+    addWgt->setObjectName("addwgt");
+    addWgt->setMinimumSize(QSize(580, 50));
+    addWgt->setMaximumSize(QSize(960, 50));
+    addWgt->setStyleSheet("HoverWidget#addwgt{background: palette(button); border-radius: 4px;}HoverWidget:hover:!pressed#addwgt{background: #3D6BE5; border-radius: 4px;}");
+
+    QHBoxLayout *addLyt = new QHBoxLayout;
+
+    QLabel * iconLabel = new QLabel();
+    QLabel * textLabel = new QLabel(tr("Add autoboot app "));
+    QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+    iconLabel->setPixmap(pixgray);
+    addLyt->addWidget(iconLabel);
+    addLyt->addWidget(textLabel);
+    addLyt->addStretch();
+    addWgt->setLayout(addLyt);
+
+    // 悬浮改变Widget状态
+    connect(addWgt, &HoverWidget::enterWidget, this, [=](QString mname){
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "white", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(base);");
+
+    });
+    // 还原状态
+    connect(addWgt, &HoverWidget::leaveWidget, this, [=](QString mname){
+        QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
+        iconLabel->setPixmap(pixgray);
+        textLabel->setStyleSheet("color: palette(windowText);");
+    });
+
+    connect(addWgt, &HoverWidget::widgetClicked, this, [=](QString mname){
+        dialog->exec();
+    });
+
+    ui->addLyt->addWidget(addWgt);
+
+}
+
 void AutoBoot::initUI(){
     _walk_config_dirs();
 
@@ -117,14 +167,16 @@ void AutoBoot::initUI(){
     int num = statusMaps.count();
 
     //显示全部ITEM，设置高
-    ui->listWidget->setFixedHeight(num * ITEMHEIGHT + HEADHEIGHT);
-
+//    ui->listWidget->setFixedHeight(num * ITEMHEIGHT + HEADHEIGHT);
 
     //构建行头基础Widget
-    QWidget * headbaseWidget = new QWidget;
-    headbaseWidget->setAttribute(Qt::WA_DeleteOnClose);
+    QFrame * headbaseFrame = new QFrame;
+    headbaseFrame->setMinimumWidth(550);
+    headbaseFrame->setMaximumWidth(960);
+    headbaseFrame->setFrameShape(QFrame::Shape::Box);
+    headbaseFrame->setAttribute(Qt::WA_DeleteOnClose);
 
-    QVBoxLayout * headbaseVerLayout = new QVBoxLayout(headbaseWidget);
+    QVBoxLayout * headbaseVerLayout = new QVBoxLayout(headbaseFrame);
     headbaseVerLayout->setSpacing(0);
     headbaseVerLayout->setContentsMargins(0, 0, 0, 2);
 
@@ -138,7 +190,7 @@ void AutoBoot::initUI(){
     headWidget->setAttribute(Qt::WA_DeleteOnClose);
     headWidget->setObjectName("headWidget");
 //    headWidget->setFixedHeight(36);
-    headWidget->setStyleSheet("QWidget#headWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
+//    headWidget->setStyleSheet("QWidget#headWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
 
     QHBoxLayout * headHorLayout = new QHBoxLayout(headWidget);
     headHorLayout->setSpacing(16);
@@ -150,7 +202,7 @@ void AutoBoot::initUI(){
 //    nameLabel->setSizePolicy(nameSizePolicy);
     nameLabel->setFixedWidth(220);
     nameLabel->setText(tr("Name"));
-    nameLabel->setStyleSheet("background: #F4F4F4;");
+//    nameLabel->setStyleSheet("background: #F4F4F4;");
 
     QLabel * statusLabel = new QLabel(headWidget);
 //    QSizePolicy statusSizePolicy = statusLabel->sizePolicy();
@@ -158,7 +210,7 @@ void AutoBoot::initUI(){
 //    statusLabel->setSizePolicy(statusSizePolicy);
     statusLabel->setFixedWidth(68);
     statusLabel->setText(tr("Status"));
-    statusLabel->setStyleSheet("background: #F4F4F4;");
+//    statusLabel->setStyleSheet("background: #F4F4F4;");
 
     headHorLayout->addWidget(nameLabel);
     headHorLayout->addStretch();
@@ -170,19 +222,24 @@ void AutoBoot::initUI(){
     headbaseVerLayout->addWidget(headWidget);
     headbaseVerLayout->addStretch();
 
-    headbaseWidget->setLayout(headbaseVerLayout);
+//    headbaseFrame->setLayout(headbaseVerLayout);
 
-    QListWidgetItem * hItem = new QListWidgetItem(ui->listWidget);
-    hItem->setSizeHint(QSize(ITEMWIDTH, HEADHEIGHT));
-    ui->listWidget->setItemWidget(hItem, headbaseWidget);
+//    QListWidgetItem * hItem = new QListWidgetItem(ui->listWidget);
+//    hItem->setSizeHint(QSize(ITEMWIDTH, HEADHEIGHT));
+//    ui->listWidget->setItemWidget(hItem, headbaseFrame);
+    ui->autoLayout->addWidget(headbaseFrame);
 
     //构建每个启动项
     QSignalMapper * checkSignalMapper = new QSignalMapper(this);
     QMap<QString, AutoApp>::iterator it = statusMaps.begin();
     for (int index = 0; it != statusMaps.end(); it++, index++){
         QString bname = it.value().bname;
+        QString appName = it.value().name;
 
-        QWidget * baseWidget = new QWidget;
+        QFrame * baseWidget = new QFrame;
+        baseWidget->setMinimumWidth(550);
+        baseWidget->setMaximumWidth(960);
+        baseWidget->setFrameShape(QFrame::Shape::Box);
         baseWidget->setAttribute(Qt::WA_DeleteOnClose);
 
         QVBoxLayout * baseVerLayout = new QVBoxLayout(baseWidget);
@@ -198,7 +255,7 @@ void AutoBoot::initUI(){
         widget->setMaximumHeight(60);
 
         widget->setAttribute(Qt::WA_DeleteOnClose);
-        widget->setStyleSheet("background: #F4F4F4;");
+//        widget->setStyleSheet("background: #F4F4F4;");
 
         QHBoxLayout * mainHLayout = new QHBoxLayout(widget);
         mainHLayout->setContentsMargins(16, 0, 32, 0);
@@ -207,12 +264,12 @@ void AutoBoot::initUI(){
         QLabel * iconLabel = new QLabel(widget);
         iconLabel->setFixedSize(32, 32);
         iconLabel->setPixmap(it.value().pixmap);
-        iconLabel->setStyleSheet("background: #F4F4F4");
+//        iconLabel->setStyleSheet("background: #F4F4F4");
 
         QLabel * textLabel = new QLabel(widget);
-        textLabel->setStyleSheet("background: #F4F4F4");
+//        textLabel->setStyleSheet("background: #F4F4F4");
         textLabel->setFixedWidth(250);
-        textLabel->setText(bname);
+        textLabel->setText(appName);
 
         SwitchButton * button = new SwitchButton();
         button->setAttribute(Qt::WA_DeleteOnClose);
@@ -229,9 +286,9 @@ void AutoBoot::initUI(){
         connect(dBtn, &QPushButton::clicked, this, [=]{
             del_autoboot_realize(bname);
         });
-        dBtn->setStyleSheet(""
-                            "QPushButton{background: #FA6056; border-radius: 2px;}"
-                            "QPushButton:hover:pressed{background: #E54A50; border-radius: 2px;}");
+//        dBtn->setStyleSheet(""
+//                            "QPushButton{background: #FA6056; border-radius: 2px;}"
+//                            "QPushButton:hover:pressed{background: #E54A50; border-radius: 2px;}");
 
         QLabel * pLabel = new QLabel(widget);
         pLabel->setFixedSize(QSize(32, 32));
@@ -267,9 +324,11 @@ void AutoBoot::initUI(){
 
         baseWidget->setLayout(baseVerLayout);
 
-        QListWidgetItem * item = new QListWidgetItem(ui->listWidget);
-        item->setSizeHint(QSize(ITEMWIDTH, ITEMHEIGHT));
-        ui->listWidget->setItemWidget(item, baseWidget);
+//        QListWidgetItem * item = new QListWidgetItem(ui->listWidget);
+//        item->setSizeHint(QSize(ITEMWIDTH, ITEMHEIGHT));
+//        ui->listWidget->setItemWidget(item, baseWidget);
+//        ui->listWidget->setSpacing(1);
+        ui->autoLayout->addWidget(baseWidget);
     }
     connect(checkSignalMapper, SIGNAL(mapped(QString)), this, SLOT(checkbox_changed_cb(QString)));
 }
@@ -319,6 +378,19 @@ bool AutoBoot::_copy_desktop_file_to_local(QString bname){
     return true;
 }
 
+void AutoBoot::clearAutoItem()
+{
+    if (ui->autoLayout->layout() != NULL) {
+        QLayoutItem* item;
+        while ((item = ui->autoLayout->layout()->takeAt(0)) != NULL )
+        {
+            delete item->widget();
+            delete item;
+        }
+//        delete ui->availableLayout->layout();
+    }
+}
+
 bool AutoBoot::_delete_local_autoapp(QString bname){
     char * dstpath;
 
@@ -427,7 +499,8 @@ bool AutoBoot::_delete_autoapp(QString bname){
     }
 
     //刷新界面
-    ui->listWidget->clear();
+//    ui->listWidget->clear();
+    clearAutoItem();
     initUI();
 
     g_free(dstpath);
@@ -574,7 +647,7 @@ AutoApp AutoBoot::_app_new(const char *path){
     shown = _key_file_get_shown(keyfile, g_getenv("XDG_CURRENT_DESKTOP"));
     name = g_key_file_get_locale_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_NAME, NULL, NULL);
     comment = g_key_file_get_locale_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_COMMENT, NULL, NULL);
-    exec = g_key_file_get_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, NULL);
+    exec = g_key_file_get_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, NULL);    
     icon = g_key_file_get_locale_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_ICON, NULL, NULL);
 
     app.bname = QString::fromUtf8(bname);
@@ -737,7 +810,8 @@ void AutoBoot::add_autoboot_realize_slot(QString path, QString name, QString exe
     g_free(filepath);
 
     //refresh
-    ui->listWidget->clear();
+//    ui->listWidget->clear();
+    clearAutoItem();
     initUI();
 
 }
@@ -761,11 +835,31 @@ void AutoBoot::del_autoboot_realize(QString bname){
 //    }
 //    else if (it.value().xdg_position == LOCALPOS){ //删除
         _delete_local_autoapp(bname);
-        ui->listWidget->clear();
+//        ui->listWidget->clear();
+        clearAutoItem();
         initUI();
-//    }
+        //    }
 }
 
+
+
+//bool AutoBoot::eventFilter(QObject *watched, QEvent *event)
+//{
+//    if (watched == ui->addFrame){
+//        if (event->type() == QEvent::MouseButtonPress){
+//            QMouseEvent * mouseEvent = static_cast<QMouseEvent *>(event);
+//            if (mouseEvent->button() == Qt::LeftButton){
+//                AddAutoBoot * mdialog = new AddAutoBoot();
+//                mdialog->exec();
+//                dialog->exec();
+//                return true;
+//            } else
+//                return false;
+//        }
+//    }
+//    return QObject::eventFilter(watched, event);
+//}
+
 void AutoBoot::checkbox_changed_cb(QString bname){
     foreach (QString key, appgroupMultiMaps.keys()) {
         if (key == bname){
