@@ -39,31 +39,9 @@ DefaultApp::DefaultApp(){
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
     ui->setupUi(pluginWidget);
 
-    itemDelege = new QStyledItemDelegate();
-
-    pluginName = tr("defaultapp");
+    pluginName = tr("Defaultapp");
     pluginType = SYSTEM;
-
-
-    pluginWidget->setStyleSheet("background: #ffffff;");
-
-    ui->browserWidget->setStyleSheet("QWidget#browserWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
-    ui->browserLabel->setStyleSheet("QLabel#browserLabel{background: #F4F4F4;}");
-
-    ui->mailWidget->setStyleSheet("QWidget#mailWidget{background: #F4F4F4;}");
-    ui->mailLabel->setStyleSheet("QLabel#mailLabel{background: #F4F4F4;}");
-
-    ui->imageWidget->setStyleSheet("QWidget#imageWidget{background: #F4F4F4;}");
-    ui->imageLabel->setStyleSheet("QLabel#imageLabel{background: #F4F4F4;}");
-
-    ui->audioWidget->setStyleSheet("QWidget#audioWidget{background: #F4F4F4;}");
-    ui->audioLabel->setStyleSheet("QLabel#audioLabel{background: #F4F4F4;}");
-
-    ui->videoWidget->setStyleSheet("QWidget#videoWidget{background: #F4F4F4;}");
-    ui->videoLabel->setStyleSheet("QLabel#videoLabel{background: #F4F4F4;}");
-
-    ui->textWidget->setStyleSheet("QWidget#textWidget{background: #F4F4F4; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
-    ui->textLabel->setStyleSheet("QLabel#textLabel{background: #F4F4F4;}");
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
     initUI();
 
@@ -92,29 +70,10 @@ void DefaultApp::plugin_delay_control(){
 
 void DefaultApp::initUI(){
 //    ui->browserComBoBox->setView(new QListView());
-    ui->browserComBoBox->setItemDelegate(itemDelege);
-    ui->browserComBoBox->setMaxVisibleItems(5);
-
-    ui->mailComBoBox->setItemDelegate(itemDelege);
-    ui->mailComBoBox->setMaxVisibleItems(5);
-
-    ui->imageComBoBox->setItemDelegate(itemDelege);
-    ui->imageComBoBox->setMaxVisibleItems(5);
-
-    ui->audioComBoBox->setItemDelegate(itemDelege);
-    ui->audioComBoBox->setMaxVisibleItems(5);
-
-    ui->videoComBoBox->setItemDelegate(itemDelege);
-    ui->videoComBoBox->setMaxVisibleItems(5);
-
-    ui->textComBoBox->setItemDelegate(itemDelege);
-    ui->textComBoBox->setMaxVisibleItems(5);
-
 
     // BROWSER
     int browserindex = -1;
     QString currentbrowser(getDefaultAppId(BROWSERTYPE)); //获取当前
-
     AppList * list = getAppIdList(BROWSERTYPE); //获取可选列表
     if (list){
         for (int i = 0; list[i].appid != NULL; i++){
@@ -135,9 +94,8 @@ void DefaultApp::initUI(){
         }
         free(list);
     }
-//    ui->browserComBoBox->addItem("add", "add");
     ui->browserComBoBox->setCurrentIndex(browserindex);
-
+    browserComBoBox_changed_cb(browserindex);
     connect(ui->browserComBoBox, SIGNAL(currentIndexChanged(int)), this, SLOT(browserComBoBox_changed_cb(int)));
 
     // MAIL
@@ -164,7 +122,7 @@ void DefaultApp::initUI(){
         free(maillist);
     }
     ui->mailComBoBox->setCurrentIndex(mailindex);
-
+    mailComBoBox_changed_cb(mailindex);
     connect(ui->mailComBoBox, SIGNAL(currentIndexChanged(int)), this, SLOT(mailComBoBox_changed_cb(int)));
 
     // IMAGE
@@ -191,7 +149,7 @@ void DefaultApp::initUI(){
         free(imagelist);
     }
     ui->imageComBoBox->setCurrentIndex(imageindex);
-
+    imageComBoBox_changed_cb(imageindex);
     connect(ui->imageComBoBox, SIGNAL(currentIndexChanged(int)), this, SLOT(imageComBoBox_changed_cb(int)));
 
     // AUDIO
@@ -218,7 +176,7 @@ void DefaultApp::initUI(){
         free(audiolist);
     }
     ui->audioComBoBox->setCurrentIndex(audioindex);
-
+    audioComBoBox_changed_cb(audioindex);
     connect(ui->audioComBoBox, SIGNAL(currentIndexChanged(int)), this, SLOT(audioComBoBox_changed_cb(int)));
 
     // VIDEO
@@ -245,7 +203,7 @@ void DefaultApp::initUI(){
         free(videolist);
     }
     ui->videoComBoBox->setCurrentIndex(videoindex);
-
+    videoComBoBox_changed_cb(videoindex);
     connect(ui->videoComBoBox, SIGNAL(currentIndexChanged(int)), this, SLOT(videoComBoBox_changed_cb(int)));
 
     // TEXT
@@ -272,7 +230,7 @@ void DefaultApp::initUI(){
         free(textlist);
     }
     ui->textComBoBox->setCurrentIndex(textindex);
-
+    textComBoBox_changed_cb(textindex);
     connect(ui->textComBoBox, SIGNAL(currentIndexChanged(int)), this, SLOT(textComBoBox_changed_cb(int)));
 }
 
@@ -313,6 +271,8 @@ void DefaultApp::imageComBoBox_changed_cb(int index){
 }
 
 void DefaultApp::audioComBoBox_changed_cb(int  index){
+    qDebug() << "this is audio:" << endl;
+
     QString appid = ui->audioComBoBox->itemData(index).toString();
     if (appid == "add"){
         qDebug() << "add clicked";
@@ -426,7 +386,8 @@ bool DefaultApp::setWebBrowsersDefaultProgram(char * appid){
                 gboolean ret1=g_app_info_set_as_default_for_type(appitem, "x-scheme-handler/http", NULL);
                 gboolean ret2=g_app_info_set_as_default_for_type(appitem, "x-scheme-handler/https", NULL);
                 gboolean ret3=g_app_info_set_as_default_for_type(appitem, "x-scheme-handler/about", NULL);
-                if(ret1 && ret2 && ret3)
+                gboolean ret4=g_app_info_set_as_default_for_type(appitem, "text/html", NULL);
+                if(ret1 && ret2 && ret3 && ret4)
                     judge=true;
                 break;
             }
@@ -536,8 +497,16 @@ bool DefaultApp::setAudioPlayersDefaultProgram(char *appid){
                 gboolean ret3 = g_app_info_set_as_default_for_type(appitem, "audio/x-scpls", NULL);
                 gboolean ret4 = g_app_info_set_as_default_for_type(appitem, "audio/x-vorbis+ogg", NULL);
                 gboolean ret5 = g_app_info_set_as_default_for_type(appitem, "audio/x-wav", NULL);
-                if(ret1 && ret2 && ret3 && ret4 && ret5)
+                gboolean ret6 = g_app_info_set_as_default_for_type(appitem, "audio/x-ms-wma", NULL);
+                gboolean ret7 = g_app_info_set_as_default_for_type(appitem, "audio/x-flac", NULL);
+                gboolean ret8 = g_app_info_set_as_default_for_type(appitem, "audio/ac3", NULL);
+                gboolean ret9 = g_app_info_set_as_default_for_type(appitem, "audio/acc", NULL);
+                gboolean ret10 = g_app_info_set_as_default_for_type(appitem, "audio/aac", NULL);
+                gboolean ret11 = g_app_info_set_as_default_for_type(appitem, "audio/mp4", NULL);
+                if(ret1 && ret2 && ret3 && ret4 && ret5 && ret6 && ret7 && ret8 && ret9 && ret10 && ret11) {
+                    qDebug()<<"set succes in default app----->"<<endl;
                     judge=true;
+                }
                 break;
             }
         }
