@@ -3,9 +3,11 @@
 
 #include <QTimer>
 #include <QDialog>
-#include <QGSettings/QGSettings>
+#include <QGSettings>
 #include <QListView>
 #include <QFile>
+#include <QPainter>
+#include <QPainterPath>
 
 namespace Ui {
 class DataFormat;
@@ -19,10 +21,14 @@ public:
     explicit DataFormat(QWidget *parent = nullptr);
     ~DataFormat();
 
+protected:
+    void paintEvent(QPaintEvent *);
+
 private:
     QTimer *m_itimer;
     QGSettings *m_gsettings = nullptr;
     QString qss;
+    QString locale;
 
 private:
     Ui::DataFormat *ui;
