@@ -26,6 +26,7 @@
 #include <QShowEvent>
 #include <QMoveEvent>
 #include <QHideEvent>
+#include <QPainter>
 
 #include "interface.h"
 #include "homepagewidget.h"
@@ -54,6 +55,10 @@ public:
     void bootOptionsFilter(QString opt);
     void bootOptionsSwitch(int moduleNum, int funcNum);
 
+protected:
+    void paintEvent(QPaintEvent *);
+    bool eventFilter(QObject *watched, QEvent *event);
+
 private:
     Ui::MainWindow *ui;
 
@@ -75,12 +80,19 @@ private:
     void setBtnLayout(QPushButton * &pBtn);
     void loadPlugins();
     void initLeftsideBar();
-    QPushButton * buildLeftsideBtn(QString bname);
+    QPushButton * buildLeftsideBtn(QString bname, QString tipName);
+    bool isExitsCloudAccount();
+
+    // load svg picture
+    const QPixmap loadSvg(const QString &fileName, QString color);
+    // chang svg picture's color
+    QPixmap drawSymbolicColoredPixmap(const QPixmap &source, QString color);
+
+    bool dblOnEdge(QMouseEvent *event);
 
 public slots:
     void functionBtnClicked(QObject * plugin);
     void sltMessageReceived(const QString &msg);
-
 };
 
 #endif // MAINWINDOW_H
